/*
 * Author(s) kkaok
 * Date: 2003.03.14
 * Copyright kkaok,  All Rights Reserved.
 */
package kr.pe.kkaok.board.dao;

import java.sql.Connection;
import java.sql.Statement;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;
import java.io.File;
import kr.pe.kkaok.jdbc.DBManager;
import kr.pe.kkaok.util.Utility;
import kr.pe.kkaok.util.ReplaceUtil;
import kr.pe.kkaok.util.ParamUtil;
import kr.pe.kkaok.board.upload.UploadBoard;

public class MsBoardDAOImpl implements KBoardDAO
{
    private static final String QUERY1 = "select skin,tbTitle,attach_key,editmode,image_allow,tbCnt,tbInfoStatus from tablemng where tbName=?";
    private static final String QUERY2 = "select seq,writeday,title,readnum from tablemnginfo where (tbName = ? or tbName = 'kkaok') and viewSelect= '1'";
    private static final String QUERY3 = "update tablemnginfo set readnum = readnum + 1 where seq = ?";
    private static final String QUERY4 = "select title,content,imgInfo,writeday,readnum from tablemnginfo where seq = ? ";
    private static final String QUERY5 = "select tbidx,com_name,com_memo,com_writeday,com_pwd from commentmng where tbName=? and seq=? order by tbidx";
    private static final String QUERY6 = "insert into commentmng (tbName,seq,com_name,com_memo,com_writeday,com_pwd) values(?,?,?,?,getdate(),?)";
    private static final String QUERY7 = "select count(*) as cnt from commentmng where tbName=? and seq=?";
    private static final String QUERY8 = "delete from commentmng where tbidx = ?";
    private static final String QUERY9 = "delete from downloadmng where tbidx = ?";
    private static final String QUERY10 = "select filename from downloadmng where tbName=? and seq =?";
    private static final String QUERY11 = "delete from downloadmng where tbName = ? and seq = ?";
    private static final String QUERY12 = "delete from commentmng where tbName = ? and seq = ?";
    private static final String QUERY13 = "update tablemng set tbCnt=? where tbName=?";
    private static final String QUERY14 = "select com_pwd from commentmng where tbidx = ?";
    private static final String QUERY15 = "insert into downloadmng (tbName,seq,fileName,fileSize,downCnt) values(?,?,?,?,0)";
    private static final String QUERY16 = "select title,content from tablemnginfo where seq = ? ";

    public SkinTable getSkinData(String tableName) throws Exception
    {
        SkinTable sTable = new SkinTable();
        ResultSet rs = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY1);
            pstmt.setString(1,tableName);
            rs = pstmt.executeQuery();
            if (rs.next()) {
                sTable.setSkin(rs.getString("skin"));
                sTable.setTbTitle(rs.getString("tbTitle"));
                sTable.setAttach_key(rs.getString("attach_key"));
                sTable.setEditmode(rs.getString("editmode"));
                sTable.setImage_allow(rs.getString("image_allow"));
                sTable.setTbCnt(rs.getInt("tbCnt"));
                sTable.setTbInfoStatus(rs.getString("tbInfoStatus"));
            }
        } finally {
            DBManager.close(rs,pstmt,conn);
        }
        return sTable;
    }

    public List getListData(String tableName,int gotoPage,int pageSize,int recordCount) throws Exception
    {
		int start = pageSize*gotoPage;
		if (start > recordCount) pageSize -= (start-recordCount);
        StringBuffer query = new StringBuffer(); 
		query.append("select seq,name,title,email,readnum,writeday,re_level,relativeCnt from (select top ");
		query.append(pageSize+" seq,name,title,email,readnum,writeday,re_level,relativeCnt,re_step from (select top ");
		query.append(start+" seq,name,title,email,readnum,writeday,re_level,relativeCnt,re_step from "+tableName);
		query.append(" order by re_step desc) as DERIVEDTBL order by re_step)as DERIVEDTBL order by re_step desc");
    	
        List listData = new ArrayList();
        BoardTable bTable = null;
    	ResultSet rs = null;
    	PreparedStatement pstmt = null;
    	Connection conn = null;
    	try{
    	    conn = DBManager.getConnection();
    	    pstmt = conn.prepareStatement(query.toString());
    	    rs = pstmt.executeQuery();
    	    while(rs.next()){
                bTable = new BoardTable();
                bTable.setSeq(rs.getInt("seq"));
                bTable.setName(rs.getString("name"));
                bTable.setTitle(Utility.getTitleLimit(ReplaceUtil.encodeHTMLSpecialChar(rs.getString("title"),14),40,rs.getInt("re_level")));
                bTable.setEmail(rs.getString("email"));
                bTable.setReadnum(rs.getInt("readnum"));
                bTable.setWriteday(rs.getTimestamp("writeday"));
                bTable.setRe_level(rs.getInt("re_level"));
                bTable.setRelativeCnt(rs.getInt("relativeCnt"));
                listData.add(bTable);
    	    }
    	} finally{
    	    DBManager.close(pstmt,conn);
    	}
        return listData;
    }

    public List getListData(String tableName,int gotoPage,int pageSize) throws Exception
    {
        int start = pageSize*(gotoPage-1)+1;
        ResultSet rs = null;
        PreparedStatement pstmt = null;
        Connection conn = null;

        String query = "select min(re_step) AS Expr1 from (select top "+start+" re_step from "+tableName+" order by re_step desc) as DERIVEDTBL";
        int pageTopNum = 0; 
        
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(query);
            rs = pstmt.executeQuery();
            if(rs.next()) pageTopNum = rs.getInt("Expr1");
        } finally {
            DBManager.close(rs,pstmt,conn);
        }

        List listData = new ArrayList();
        BoardTable bTable = null;
        query = "select top "+pageSize+" seq,name,title,email,readnum,writeday,re_level,relativeCnt from "+tableName+" where re_step <= ? order by re_step desc";
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(query);
            pstmt.setInt(1,pageTopNum);
            rs = pstmt.executeQuery();
            while (rs.next()){
                bTable = new BoardTable();
                bTable.setSeq(rs.getInt("seq"));
                bTable.setName(rs.getString("name"));
                bTable.setTitle(Utility.getTitleLimit(ReplaceUtil.encodeHTMLSpecialChar(rs.getString("title"),14),40,rs.getInt("re_level")));
                bTable.setEmail(rs.getString("email"));
                bTable.setReadnum(rs.getInt("readnum"));
                bTable.setWriteday(rs.getTimestamp("writeday"));
                bTable.setRe_level(rs.getInt("re_level"));
                bTable.setRelativeCnt(rs.getInt("relativeCnt"));
                listData.add(bTable);
            }  
        } finally {
            DBManager.close(rs,pstmt,conn);
        }
        return listData;
    }

    public int getSearchCount(String tableName,String search,String findword) throws Exception
    {
        int recordCount = 0;
        String query = "select count(re_step) recordCount from "+tableName+" where "+ search +" like ? ";

        ResultSet rs = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(query);
            pstmt.setString(1,"%"+findword+"%");
            rs = pstmt.executeQuery();
            if(rs.next()) recordCount = rs.getInt("recordCount");
        } finally {
            DBManager.close(rs,pstmt,conn);
        }
        return recordCount;
    }

    public List getSearchData(String tableName,String search,String findword,int gotoPage,int pageSize) throws Exception
    {
        int start = pageSize*(gotoPage-1)+1;
        ResultSet rs = null;
        PreparedStatement pstmt = null;
        Connection conn = null;

        String query = "select min(re_step) AS Expr1 from (select top "+start+" re_step from "+tableName+" where "+ search +" like ? order by re_step desc) as DERIVEDTBL";
        int pageTopNum = 0; 

        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(query);
            pstmt.setString(1,"%"+findword+"%");
            rs = pstmt.executeQuery();
            if(rs.next()) pageTopNum = rs.getInt("Expr1");
        } finally {
            DBManager.close(rs,pstmt,conn);
        }

        List listData = new ArrayList();
        BoardTable bTable = null;
        query = "select top "+pageSize+" seq,name,title,email,readnum,writeday,re_level,relativeCnt from "+tableName+" where re_step <= ? and "+ search +" like ? order by re_step desc";
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(query);
            pstmt.setInt(1,pageTopNum);
            pstmt.setString(2,"%"+findword+"%");
            rs = pstmt.executeQuery();
            while (rs.next()){
                bTable = new BoardTable();
                bTable.setSeq(rs.getInt("seq"));
                bTable.setName(rs.getString("name"));
                bTable.setTitle(Utility.getTitleLimit(ReplaceUtil.encodeHTMLSpecialChar(rs.getString("title"),14),40,rs.getInt("re_level")));
                bTable.setEmail(rs.getString("email"));
                bTable.setReadnum(rs.getInt("readnum"));
                bTable.setWriteday(rs.getTimestamp("writeday"));
                bTable.setRe_level(rs.getInt("re_level"));
                bTable.setRelativeCnt(rs.getInt("relativeCnt"));
                listData.add(bTable);
            }  
        } finally {
            DBManager.close(rs,pstmt,conn);
        }
        return listData;
    }     

    public List getSearchData(String tableName,String search,String findword,int gotoPage,
    		int pageSize,int recordCount) throws Exception
    {
		int start = pageSize*gotoPage;
		if (start > recordCount) pageSize -= (start-recordCount);
        StringBuffer query = new StringBuffer(); 
		query.append("select seq,name,title,email,readnum,writeday,re_level,relativeCnt from (select top ");
		query.append(pageSize+" seq,name,title,email,readnum,writeday,re_level,relativeCnt,re_step from (select top ");
		query.append(start+" seq,name,title,email,readnum,writeday,re_level,relativeCnt,re_step from "+tableName);
		query.append(" where "+ search +" like ? order by re_step desc) as DERIVEDTBL order by re_step)as DERIVEDTBL order by re_step desc");

        ResultSet rs = null;
        PreparedStatement pstmt = null;
        Connection conn = null;

        List listData = new ArrayList();
        BoardTable bTable = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(query.toString());
            pstmt.setString(1,"%"+findword+"%");
            rs = pstmt.executeQuery();
            while (rs.next()){
                bTable = new BoardTable();
                bTable.setSeq(rs.getInt("seq"));
                bTable.setName(rs.getString("name"));
                bTable.setTitle(Utility.getTitleLimit(ReplaceUtil.encodeHTMLSpecialChar(rs.getString("title"),14),40,rs.getInt("re_level")));
                bTable.setEmail(rs.getString("email"));
                bTable.setReadnum(rs.getInt("readnum"));
                bTable.setWriteday(rs.getTimestamp("writeday"));
                bTable.setRe_level(rs.getInt("re_level"));
                bTable.setRelativeCnt(rs.getInt("relativeCnt"));
                listData.add(bTable);
            }  
        } finally {
            DBManager.close(rs,pstmt,conn);
        }
        return listData;
    }     

    public List getInfoList(String tableName) throws Exception
    {
        List infoData = new ArrayList();
        InfoTable iTable = null;
        ResultSet rs = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY2);
            pstmt.setString(1,tableName);
            rs = pstmt.executeQuery();
            while (rs.next()){
                iTable = new InfoTable();
                iTable.setSeq(rs.getInt("seq"));
                iTable.setTitle(Utility.getTitleLimit(ReplaceUtil.encodeHTMLSpecialChar(rs.getString("title"),14),38));
                iTable.setWriteday(rs.getTimestamp("writeday"));
                iTable.setReadnum(rs.getInt("readnum"));
                infoData.add(iTable);
            }
        } finally {
            DBManager.close(rs,pstmt,conn);
        }
        return infoData;
    }

    public void doHitPlus(int seq) throws Exception
    {
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY3);
            pstmt.setInt(1,seq);
            pstmt.executeUpdate();
        } finally {
            DBManager.close(pstmt,conn);
        }
    }

    public void doHitPlus(String tableName,int seq) throws Exception
    {
        String sql = "update "+tableName+" set readnum = readnum + 1 where seq =?";
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(sql);
            pstmt.setInt(1,seq);
            pstmt.executeUpdate();
        } finally {
            DBManager.close(pstmt,conn);
        }
    }
 
    public InfoTable getInfoData(int seq) throws Exception
    {
        InfoTable iTable = new InfoTable();
        ResultSet rs = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY4);
            pstmt.setInt(1,seq);
            rs = pstmt.executeQuery();
            if (rs.next()) {
                iTable.setTitle(rs.getString("title"));
                iTable.setContent(rs.getString("content"));
                iTable.setImgInfo(rs.getString("imgInfo"));
                iTable.setWriteday(rs.getTimestamp("writeday"));
                iTable.setReadnum(rs.getInt("readnum"));
            }
        } finally {
            DBManager.close(rs,pstmt,conn);
        }
        return iTable;
    }

    public List getDownloadData(String tableName,int seq) throws Exception
    {
        List downloadData = new ArrayList();
        String query = "select tbidx,fileName,fileSize,downCnt from "+tableName+" where seq=?";
        DownloadTable dTable = null;
        ResultSet rs    = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(query);
            pstmt.setInt(1,seq);
            rs = pstmt.executeQuery();
            while (rs.next()){
                dTable = new DownloadTable();
                dTable.setTbidx(rs.getInt("tbidx"));
                dTable.setFileName(rs.getString("fileName"));
                dTable.setFileSize(rs.getString("fileSize"));
                dTable.setDownCnt(rs.getInt("downCnt"));
                downloadData.add(dTable);
            }
        } finally {
            DBManager.close(rs,pstmt,conn);
        }
        return downloadData;
    }

    public List getDownloadData(String tableName, String tbName, int seq) throws Exception
    {
        List downloadData = new ArrayList();
        String query = "select tbidx,fileName,fileSize,downCnt from "+tableName+" where tbName=? and seq=?";
        DownloadTable dTable = null;
        ResultSet rs    = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(query);
            pstmt.setString(1,tbName);
            pstmt.setInt(2,seq);
            rs = pstmt.executeQuery();
            while (rs.next()){
                dTable = new DownloadTable();
                dTable.setTbidx(rs.getInt("tbidx"));
                dTable.setFileName(rs.getString("fileName"));
                dTable.setFileSize(rs.getString("fileSize"));
                dTable.setDownCnt(rs.getInt("downCnt"));
                downloadData.add(dTable);
            }
        } finally {
            DBManager.close(rs,pstmt,conn);
        }
        return downloadData;
    }

    public BoardTable getViewData(String tableName,int seq,boolean authority,String contextRoot) throws Exception
    {
        BoardTable bTable = new BoardTable();
        String query = " select re_step,re_level,name,title,email,content,homepage,imgInfo,writeday,readnum,ip,relativeCnt,pwd,tag from "+tableName+" where seq = ? ";
        ResultSet rs = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(query);
            pstmt.setInt(1,seq);
            rs = pstmt.executeQuery();
            if (rs.next()) {
                bTable.setRe_step(rs.getInt("re_step"));
                bTable.setRe_level(rs.getInt("re_level"));
                bTable.setName(rs.getString("name"));
                bTable.setTitle(rs.getString("title"));

                if(rs.getString("homepage") != null && !rs.getString("homepage").equals("")) {
                    if(rs.getString("homepage").indexOf("http://")>-1) 
                        bTable.setHomepage("<a href='"+rs.getString("homepage")+"' target=_blank><img src='"+contextRoot+"/kBoard/images/home.gif' border=0></a>");
                    else 
                        bTable.setHomepage("<a href='http://"+rs.getString("homepage")+"' target=_blank><img src='"+contextRoot+"/kBoard/images/home.gif' border=0></a>");
                }else
                	bTable.setHomepage("");
                if(rs.getString("email") != null && !rs.getString("email").equals("")) 
                    bTable.setEmail("<a href='mailto:"+rs.getString("email")+"'><img src='"+contextRoot+"/kBoard/images/email.gif' border=0></a>");
                else
                	bTable.setEmail("");

                bTable.setImgInfo(ParamUtil.getReqParameter(rs.getString("imgInfo")));
                bTable.setWriteday(rs.getTimestamp("writeday"));
                bTable.setReadnum(rs.getInt("readnum"));
                bTable.setIp(rs.getString("ip"));
                bTable.setRelativeCnt(rs.getInt("relativeCnt"));
                if (authority)
                	bTable.setPwd(rs.getString("pwd"));
                else
                	bTable.setPwd("");
                bTable.setTag(rs.getString("tag"));
                if (rs.getString("tag").equals("0")) 
                	bTable.setContent(ReplaceUtil.encodeHTMLSpecialChar(rs.getString("content"),11));
                else 
                	bTable.setContent(rs.getString("content")); 
            }
        } finally {
            DBManager.close(rs,pstmt,conn);
        }
        return bTable;
    }

    public List getCommentData(String tbName, int seq, boolean authority) throws Exception
    {
        List commentData = new ArrayList();
        CommentTable cTable = null;
        ResultSet rs   = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY5);
            pstmt.setString(1,tbName);
            pstmt.setInt(2,seq);
            rs = pstmt.executeQuery();
            while (rs.next()) {
                cTable = new CommentTable();
                cTable.setTbidx(rs.getInt("tbidx"));
                cTable.setCom_name(rs.getString("com_name"));
                cTable.setCom_memo(rs.getString("com_memo"));
                cTable.setCom_writeday(rs.getString("com_writeday"));
                if (authority)
                	cTable.setCom_pwd(rs.getString("com_pwd"));
                else
                	cTable.setCom_pwd("");
                commentData.add(cTable);
            }
        } finally {
            DBManager.close(rs,pstmt,conn);
        }
        return commentData;
    }

    public boolean getCheck(String tableName, int seq, String pwd) throws Exception
    {
        boolean ck = false;
        String query = "select pwd from "+tableName+" where seq = ?";
        ResultSet rs   = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(query);
            pstmt.setInt(1,seq);
            rs = pstmt.executeQuery();
            String chkPwd = "";
            if(rs.next()) chkPwd = rs.getString(1);
            if(chkPwd.equals(pwd)) ck = true;
        } finally {
            DBManager.close(rs,pstmt,conn);
        }
        return ck;
    }

    public BoardTable getWriteData(String tableName, int seq, String pageStatus) throws Exception
    {
        String query = " select re_step,re_level,name,title,email,content,homepage,imgInfo,tag,pwd from "+tableName+" where seq = ? ";
        BoardTable bTable = new BoardTable();
        ResultSet rs = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(query);
            pstmt.setInt(1,seq);
            rs = pstmt.executeQuery();
            if (rs.next()) {
                bTable.setRe_step(rs.getInt("re_step"));
                bTable.setRe_level(rs.getInt("re_level"));
                bTable.setEmail(rs.getString("email"));
                bTable.setTag(rs.getString("tag"));
                if (rs.getString("tag").trim().equals("0")) 
                	bTable.setContent(ReplaceUtil.encodeHTMLSpecialChar(rs.getString("content"),11));
                else 
                	bTable.setContent(rs.getString("content")); 
                if (pageStatus.equals("R")) {
                    bTable.setImgInfo("");
                    bTable.setTitle("[亯]" + rs.getString("title"));
                    bTable.setPwd("");
                }else{
	                bTable.setName(rs.getString("name"));
                    bTable.setHomepage(rs.getString("homepage"));
                    bTable.setImgInfo(rs.getString("imgInfo"));
                    bTable.setTitle(rs.getString("title"));
                    bTable.setPwd(rs.getString("pwd"));
                }
            }
        } finally {
            DBManager.close(rs,pstmt,conn);
        }
        return bTable;
    }

    public void insertComment(CommentTable cTable) throws Exception
    {
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY6);
            pstmt.setString(1,cTable.getTbName());
            pstmt.setInt(2,cTable.getSeq());
            pstmt.setString(3,cTable.getCom_name());
            pstmt.setString(4,cTable.getCom_memo());
            pstmt.setString(5,cTable.getCom_pwd());
            pstmt.executeUpdate();
        }finally{
            DBManager.close(pstmt,conn);
        }
    }
    
    public void cntPlusRelative(int seq,String tableName) throws Exception
    {
        ResultSet rs = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
        int countValue = 0;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY7);
            pstmt.setString(1,tableName);
            pstmt.setInt(2,seq);
            rs = pstmt.executeQuery();
            if(rs.next()) countValue = rs.getInt("cnt");
        }finally{
            DBManager.close(rs,pstmt,conn);
        }
        
        String sql = "update "+tableName+" set relativeCnt=? where seq = ? ";
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(sql);
            pstmt.setInt(1,countValue);
            pstmt.setInt(2,seq);
            pstmt.executeUpdate();
        }finally{
            DBManager.close(pstmt,conn);
        }
    }
    
    public void deleteComment(int tbidx) throws Exception
    {
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY8);
            pstmt.setInt(1,tbidx);
            pstmt.executeUpdate();
        }finally{
            DBManager.close(pstmt,conn);
        }
    }
    
    public void deleteFile(int tbidx) throws Exception
    {
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY9);
            pstmt.setInt(1,tbidx);
            pstmt.executeUpdate();
        }finally{
            DBManager.close(pstmt,conn);
        }
    }
    
    public void deleteAllFile(String tableName,int seq,String saveDir) throws Exception
    {
        String filename = "";
        PreparedStatement pstmt = null;
        ResultSet rs = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY10);
            pstmt.setString(1,tableName);
            pstmt.setInt(2,seq);
            rs = pstmt.executeQuery();
            while (rs.next()){
                filename = rs.getString("filename");
                if (filename.length() > 3) {
                    File delFile = new File(saveDir+filename);
                    if (delFile.exists()) delFile.delete();
                }
            }
        }finally{
            DBManager.close(rs,pstmt,conn);
        }
    }
    
    public void deleteDownload(String tableName, int seq) throws Exception
    {
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY11);
            pstmt.setString(1,tableName);
            pstmt.setInt(2,seq);
            pstmt.executeUpdate();
        }finally{
            DBManager.close(pstmt,conn);
        }
    }
    
    public void commentDelete(String tableName, int seq) throws Exception
    {
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY12);
            pstmt.setString(1,tableName);
            pstmt.setInt(2,seq);
            pstmt.executeUpdate();
        }finally{
            DBManager.close(pstmt,conn);
        }
    }
    
    public void delete(int seq,String tableName) throws Exception
    {
        String sql  = "delete from "+tableName+" where seq = ?";
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(sql);
            pstmt.setInt(1,seq);
            pstmt.executeUpdate();
        }finally{
            DBManager.close(pstmt,conn);
        }
    }
    
    public void cntPlus(String tableName) throws Exception
    {
        String sql = "select count(*) cnt from "+tableName;
        int countValue = 0;
        ResultSet rs = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(sql);
            rs = pstmt.executeQuery();
            if(rs.next()) countValue = rs.getInt("cnt");
        }finally{
            DBManager.close(rs,pstmt,conn);
        }
        
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY13);
            pstmt.setInt(1,countValue);
            pstmt.setString(2,tableName);
            pstmt.executeUpdate();
        }finally{
            DBManager.close(pstmt,conn);
        }
    }
    
    public int deletePermission(int re_step,int re_level,String tableName) throws Exception
    {
        String delSql = "Select top 1 re_level from "+tableName+" where re_step > ? and re_step <? order by re_step desc";
        int del_Level = re_level;
        ResultSet rs = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(delSql);
            pstmt.setInt(1,(int)(re_step/100)*100);
            pstmt.setInt(2,re_step);
            rs = pstmt.executeQuery();
            if(rs.next()) del_Level = rs.getInt("re_level");
        }finally{
            DBManager.close(rs,pstmt,conn);
        }
        return del_Level;
    }

    public boolean getCheckComment(int tbidx,String pwd) throws Exception
    {
        boolean ck = false;
        ResultSet rs   = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY14);
            pstmt.setInt(1,tbidx);
            rs = pstmt.executeQuery();
            String chkPwd = "";
            if(rs.next()) chkPwd = rs.getString(1);
            if(chkPwd.equals(pwd)) ck = true;
        } finally {
            DBManager.close(rs,pstmt,conn);
        }
        return ck;
    }

    public int maxRef(String tableName) throws Exception  
    {
        String sql = "select top 1 re_step from "+tableName+" order by re_step desc";
        int re = 199;
        ResultSet rs = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(sql);
            rs = pstmt.executeQuery();
            if(rs.next()) re = ((int)(rs.getInt("re_step")/100) + 1) * 100 + 99;
        }finally{
            DBManager.close(rs,pstmt,conn);
        }
        return re;
    }
     
    public void insertQuery(UploadBoard up,int re_step,int re_level) throws Exception  
    {
        PreparedStatement pstmt = null;
        Connection conn = null;
        String query = "insert into "+up.getTableName()+" (seq,re_step,re_level,name,title,pwd,email,readnum,writeday,ip,relativeCnt,homepage,imgInfo,content,tag) values(?,?,?,?,?,?,?,0,getdate(),?,0,?,?,?,?)";
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(query);
            pstmt.setInt(1,up.getSeq());
            pstmt.setInt(2,re_step);
            pstmt.setInt(3,re_level);
            pstmt.setString(4,up.getName());
            pstmt.setString(5,up.getTitle());
            pstmt.setString(6,up.getPwd());
            pstmt.setString(7,up.getEmail());
            pstmt.setString(8,up.getIp());
            pstmt.setString(9,up.getHomepage());
            pstmt.setString(10,up.getImgInfo());
            pstmt.setString(11,up.getContent());
            pstmt.setString(12,up.getTag());
            pstmt.executeUpdate();
        }finally{
            DBManager.close(pstmt,conn);
        }
    }
    
    public void getSpace(int re_step,String tableName) throws Exception
    {
        String sql = "update "+tableName+" set re_step=re_step-1 where re_step > ? and re_step < ?"; 
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(sql);
            pstmt.setInt(1,(int)(re_step/100)*100);
            pstmt.setInt(2,re_step);
            pstmt.executeUpdate();
        }finally{
            DBManager.close(pstmt,conn);
        }
    }

    public void update(UploadBoard up) throws Exception
    {
        PreparedStatement pstmt = null;
        Connection conn = null;
        String Msql = "update "+up.getTableName()+" set title=?,email=?,ip=?,homepage=?,imgInfo=?,content=?,tag=? where seq = ? ";
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(Msql);
            pstmt.setString(1,up.getTitle());
            pstmt.setString(2,up.getEmail());
            pstmt.setString(3,up.getIp());
            pstmt.setString(4,up.getHomepage());
            pstmt.setString(5,up.getImgInfo());
            pstmt.setString(6,up.getContent());
            pstmt.setString(7,up.getTag());
            pstmt.setInt(8,up.getSeq());
            pstmt.executeUpdate();
        }finally{
            DBManager.close(pstmt,conn);
        }
    }

    public void insertFile(String tableName,int seq,String filename,String filesize) throws Exception 
    {
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY15);
            pstmt.setString(1,tableName);
            pstmt.setInt(2,seq);
            pstmt.setString(3,filename);
            pstmt.setString(4,filesize);
            pstmt.executeUpdate();
        }finally{
            DBManager.close(pstmt,conn);
        }
    }

    public int maxSeq(String tableName) throws Exception 
    {
        String sql = "select top 1 seq from "+tableName+" order by seq desc";
        ResultSet rs = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(sql);
            rs = pstmt.executeQuery();
            if(rs.next()) return rs.getInt("seq")+1;
            else return 1;
        }finally{
            DBManager.close(rs,pstmt,conn);
        }
    }

    public void downloadHitCount(String tableName,int tbidx) throws Exception
    {
        String query = "update "+tableName+" set downCnt=downCnt+1 where tbidx=?";
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(query);
            pstmt.setInt(1,tbidx);
            pstmt.executeUpdate();
        }finally{
            DBManager.close(pstmt,conn);
        }
    }

    public String[] getPrintData(String tableName,int seq) throws Exception 
    {   
        String[] data = new String[2];
        String query = "select content,title,tag from "+tableName+" where seq = ? ";
        PreparedStatement pstmt = null;
        ResultSet rs = null;
        Connection conn = null;
	    try{
	    	conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(query);
            pstmt.setInt(1,seq);
            rs = pstmt.executeQuery();
            if (rs.next()) {
                data[0] = rs.getString("title");
                if (rs.getString("tag").equals("0")) 
                    data[1] = ReplaceUtil.encodeHTMLSpecialChar(rs.getString("content"),11);
                else
                    data[1] = rs.getString("content");
            }
        }finally{
	    	DBManager.close(rs,pstmt,conn);
        }
        return data;
    }

    public String getDownloadFileName(String tableName,int tbidx) throws Exception
    {
        String query = "select fileName from "+tableName+" where tbidx=?";
        PreparedStatement pstmt = null;
        ResultSet rs = null;
        Connection conn = null;
        String returnValue = "";
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(query);
            pstmt.setInt(1,tbidx);
            rs = pstmt.executeQuery();
            if (rs.next()) {
                returnValue = rs.getString("fileName");
            }
        }finally{
            DBManager.close(rs,pstmt,conn);
        }
        return returnValue;
    }

    public String[] getPrintInfoData(int seq) throws Exception 
    {   
        String[] data = new String[2];
        PreparedStatement pstmt = null;
        ResultSet rs = null;
        Connection conn = null;
	    try{
	    	conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY16);
            pstmt.setInt(1,seq);
            rs = pstmt.executeQuery();
            if (rs.next()) {
                data[0] = rs.getString("title");
                data[1] = rs.getString("content");
            }
        }finally{
	    	DBManager.close(rs,pstmt,conn);
        }
        return data;
    }
}