/*
 * Author(s) kkaok
 * Date: 2003.03.14
 * Copyright kkaok,  All Rights Reserved.
 */
package kr.pe.kkaok.board.dao;

import java.sql.Connection;
import java.sql.Statement;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;
import java.io.File;
import java.io.Reader;
import java.io.Writer;
import java.io.CharArrayReader;
import oracle.sql.*;
import oracle.jdbc.driver.*;
import kr.pe.kkaok.jdbc.DBManager;
import kr.pe.kkaok.util.Utility;
import kr.pe.kkaok.util.ReplaceUtil;
import kr.pe.kkaok.util.ParamUtil;
import kr.pe.kkaok.board.upload.UploadBoard;

public class OraBoardDAOImpl implements KBoardDAO
{
    private static final String QUERY1 = "select /*+ index(tablemng tablemng_pk_tbname) */ skin,tbTitle,attach_key,editmode,image_allow,tbCnt,tbInfoStatus from tablemng where tbName=?";
    private static final String QUERY2 = "select /*+ index(tablemnginfo tablemnginfo_indx) */ seq,writeday,title,readnum from tablemnginfo where (tbName=? or tbName='kkaok') and viewSelect='1'";
    private static final String QUERY3 = "update tablemnginfo set readnum = readnum + 1 where seq = ?";
    private static final String QUERY4 = "select /*+ index(tablemnginfo tablemnginfo_pk_seq) */ title,content,imgInfo,writeday,readnum from tablemnginfo where seq = ? ";
    private static final String QUERY5 = "select /*+ index(commentmng commentmng_indx) */ tbidx,com_name,com_memo,com_writeday,com_pwd from commentmng where tbName=? and seq=?";
    private static final String QUERY6 = "insert into commentmng (tbName,seq,tbidx,com_name,com_memo,com_writeday,com_pwd) values(?,?,commentmng_tbidx.NEXTVAL,?,?,sysdate,?)";
    private static final String QUERY8 = "delete from commentmng where tbidx = ?";
    private static final String QUERY9 = "delete from downloadmng where tbidx = ?";
    private static final String QUERY10 = "select /*+ index(downloadmng downloadmng_indx) */ filename from downloadmng where tbName=? and seq =?";
    private static final String QUERY11 = "delete from downloadmng where tbName = ? and seq = ?";
    private static final String QUERY12 = "delete from commentmng where tbName = ? and seq = ?";
    private static final String QUERY14 = "select /*+ index(commentmng commentmng_pk_tbidx) */ com_pwd from commentmng where tbidx = ?";
    private static final String QUERY15 = "insert into downloadmng (tbName,seq,tbidx,fileName,fileSize,downCnt) values(?,?,downloadmng_tbidx.NEXTVAL,?,?,0)";
    private static final String QUERY16 = "select /*+ index(tablemnginfo tablemnginfo_pk_seq) */ title,content from tablemnginfo where seq = ? ";

    public SkinTable getSkinData(String tableName) throws Exception
    {
        SkinTable sTable = new SkinTable();
        ResultSet rs = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY1);
            pstmt.setString(1,tableName);
            rs = pstmt.executeQuery();
            if (rs.next()) {
                sTable.setSkin(rs.getString("skin"));
                sTable.setTbTitle(rs.getString("tbTitle"));
                sTable.setAttach_key(rs.getString("attach_key"));
                sTable.setEditmode(rs.getString("editmode"));
                sTable.setImage_allow(rs.getString("image_allow"));
                sTable.setTbCnt(rs.getInt("tbCnt"));
                sTable.setTbInfoStatus(rs.getString("tbInfoStatus"));
            }
        } finally {
            DBManager.close(rs,pstmt,conn);
        }
        return sTable;
    }

    public List getListData(String tableName,int gotoPage,int pageSize,int recordCount) throws Exception
    {
		int start = pageSize*gotoPage;
		if (start > recordCount) pageSize -= (start-recordCount);
    	
		StringBuffer query = new StringBuffer(); 
		query.append("select seq,name,title,email,readnum,writeday,re_level,relativeCnt from (select ");
		query.append("/*+ index_desc("+tableName+" "+tableName+"_pk_re_step) */ seq,name,title,email,");
		query.append("readnum,writeday,re_level,relativeCnt,rownum as rnum from "+tableName+" where ");
		query.append("rownum <= ? order by rnum desc) where rownum <= ? order by rnum");

        List listData = new ArrayList();
        BoardTable bTable = null;
        ResultSet rs = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(query.toString());
            pstmt.setInt(1,start);
            pstmt.setInt(2,pageSize);
            rs = pstmt.executeQuery();
            while (rs.next()){
                bTable = new BoardTable();
                bTable.setSeq(rs.getInt("seq"));
                bTable.setName(rs.getString("name"));
                bTable.setTitle(Utility.getTitleLimit(ReplaceUtil.encodeHTMLSpecialChar(rs.getString("title"),14),40,rs.getInt("re_level")));
                bTable.setEmail(rs.getString("email"));
                bTable.setReadnum(rs.getInt("readnum"));
                bTable.setWriteday(rs.getTimestamp("writeday"));
                bTable.setRe_level(rs.getInt("re_level"));
                bTable.setRelativeCnt(rs.getInt("relativeCnt"));
                listData.add(bTable);
            }  
        } finally {
            DBManager.close(rs,pstmt,conn);
        }
        return listData;
    }

    public List getListData(String tableName,int gotoPage,int pageSize) throws Exception
    {
        ResultSet rs = null;
        PreparedStatement pstmt = null;
        Connection conn = null;

        int start = pageSize*(gotoPage-1)+1;
        int pageTopNum = 0; 
        String query = "select min(re_step) re_step from (select /*+ index_desc("+tableName+" "+tableName+"_pk_re_step) */ re_step from "+tableName+" where rownum <=?) DERIVEDTBL";

        try {
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(query);
            pstmt.setInt(1,start);
            rs = pstmt.executeQuery();
            if(rs.next()) pageTopNum = rs.getInt("re_step");
            else pageTopNum = 0;
        } finally {
            DBManager.close(rs,pstmt,conn);
        }

        List listData = new ArrayList();
        query = "select /*+ index_desc("+tableName+" "+tableName+"_pk_re_step) */ seq,name,title,email,readnum,writeday,re_level,relativeCnt from "+tableName+" where re_step <= ? and rownum <= ? ";
        BoardTable bTable = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(query);
            pstmt.setInt(1,pageTopNum);
            pstmt.setInt(2,pageSize);
            rs = pstmt.executeQuery();
            while (rs.next()){
                bTable = new BoardTable();
                bTable.setSeq(rs.getInt("seq"));
                bTable.setName(rs.getString("name"));
                bTable.setTitle(Utility.getTitleLimit(ReplaceUtil.encodeHTMLSpecialChar(rs.getString("title"),14),40,rs.getInt("re_level")));
                bTable.setEmail(rs.getString("email"));
                bTable.setReadnum(rs.getInt("readnum"));
                bTable.setWriteday(rs.getTimestamp("writeday"));
                bTable.setRe_level(rs.getInt("re_level"));
                bTable.setRelativeCnt(rs.getInt("relativeCnt"));
                listData.add(bTable);
            }  
        } finally {
            DBManager.close(rs,pstmt,conn);
        }
        return listData;
    }

    public int getSearchCount(String tableName,String search,String findword) throws Exception
    {
		String ex_query = "";
		if(search.equals("content")){
			ex_query = " dbms_lob.instr(content, ?)>0 ";
		}else{
			ex_query = search + " like '%'||?||'%' ";
		}

        int recordCount = 0;
        String query = "select /*+ index_desc("+tableName+" "+tableName+"_pk_re_step) */ count(re_step) recordCount from "+tableName+" where "+ ex_query;

        ResultSet rs = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(query);
            pstmt.setString(1,findword);
            rs = pstmt.executeQuery();
            if(rs.next()) recordCount = rs.getInt("recordCount");
        } finally {
            DBManager.close(rs,pstmt,conn);
        }
        return recordCount;
    }

    public List getSearchData(String tableName,String search,String findword,
    		int gotoPage,int pageSize) throws Exception
    {
		String ex_query = "";
		if(search.equals("content")){
			ex_query = " dbms_lob.instr(content, ?)>0 ";
		}else{
			ex_query = search + " like '%'||?||'%' ";
		}

        ResultSet rs = null;
        PreparedStatement pstmt = null;
        Connection conn = null;

        int start = pageSize*(gotoPage-1)+1;
        int pageTopNum = 0; 
        String query = "select min(re_step) re_step from (select /*+ index_desc("+tableName+" "+tableName+"_pk_re_step) */ re_step from "+tableName+" where "+ex_query+" and rownum <=?) DERIVEDTBL";

        try {
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(query);
            pstmt.setString(1,findword);
            pstmt.setInt(2,start);
            rs = pstmt.executeQuery();
            if(rs.next()) pageTopNum = rs.getInt("re_step");
            else pageTopNum = 0;
        } finally {
            DBManager.close(rs,pstmt,conn);
        }

        List listData = new ArrayList();
        query = "select /*+ index_desc("+tableName+" "+tableName+"_pk_re_step) */ seq,name,title,email,readnum,writeday,re_level,relativeCnt from "+tableName+" where re_step <= ? and "+ex_query+" and rownum <= ?";
        BoardTable bTable = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(query);
            pstmt.setInt(1,pageTopNum);
            pstmt.setString(2,findword);
            pstmt.setInt(3,pageSize);
            rs = pstmt.executeQuery();
            while (rs.next()){
                bTable = new BoardTable();
                bTable.setSeq(rs.getInt("seq"));
                bTable.setName(rs.getString("name"));
                bTable.setTitle(Utility.getTitleLimit(ReplaceUtil.encodeHTMLSpecialChar(rs.getString("title"),14),40,rs.getInt("re_level")));
                bTable.setEmail(rs.getString("email"));
                bTable.setReadnum(rs.getInt("readnum"));
                bTable.setWriteday(rs.getTimestamp("writeday"));
                bTable.setRe_level(rs.getInt("re_level"));
                bTable.setRelativeCnt(rs.getInt("relativeCnt"));
                listData.add(bTable);
            }  
        } finally {
            DBManager.close(rs,pstmt,conn);
        }
        return listData;
    }

    public List getSearchData(String tableName,String search,String findword,
    		int gotoPage,int pageSize,int recordCount) throws Exception
    {
		String ex_query = "";
		if(search.equals("content")){
			ex_query = " dbms_lob.instr(content, ?)>0 ";
		}else{
			ex_query = search + " like '%'||?||'%' ";
		}

		int start = pageSize*gotoPage;
		if (start > recordCount) pageSize -= (start-recordCount);
    	
		StringBuffer query = new StringBuffer(); 
		query.append("select seq,name,title,email,readnum,writeday,re_level,relativeCnt from (select ");
		query.append("/*+ index_desc("+tableName+" "+tableName+"_pk_re_step) */ seq,name,title,email,");
		query.append("readnum,writeday,re_level,relativeCnt,rownum as rnum from "+tableName+" where "+ex_query+" and ");
		query.append("rownum <= ? order by rnum desc) where rownum <= ? order by rnum");

        List listData = new ArrayList();
        BoardTable bTable = null;
        ResultSet rs = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(query.toString());
            pstmt.setString(1,findword);
            pstmt.setInt(2,start);
            pstmt.setInt(3,pageSize);
            rs = pstmt.executeQuery();
            while (rs.next()){
                bTable = new BoardTable();
                bTable.setSeq(rs.getInt("seq"));
                bTable.setName(rs.getString("name"));
                bTable.setTitle(Utility.getTitleLimit(ReplaceUtil.encodeHTMLSpecialChar(rs.getString("title"),14),40,rs.getInt("re_level")));
                bTable.setEmail(rs.getString("email"));
                bTable.setReadnum(rs.getInt("readnum"));
                bTable.setWriteday(rs.getTimestamp("writeday"));
                bTable.setRe_level(rs.getInt("re_level"));
                bTable.setRelativeCnt(rs.getInt("relativeCnt"));
                listData.add(bTable);
            }  
        } finally {
            DBManager.close(rs,pstmt,conn);
        }
        return listData;
    }     

    public List getInfoList(String tableName) throws Exception
    {
        List infoData = new ArrayList();
        InfoTable iTable = null;
        ResultSet rs = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY2);
            pstmt.setString(1,tableName);
            rs = pstmt.executeQuery();
            while (rs.next()){
                iTable = new InfoTable();
                iTable.setSeq(rs.getInt("seq"));
                iTable.setTitle(Utility.getTitleLimit(ReplaceUtil.encodeHTMLSpecialChar(rs.getString("title"),14),38));
                iTable.setWriteday(rs.getTimestamp("writeday"));
                iTable.setReadnum(rs.getInt("readnum"));
                infoData.add(iTable);
            }
        } finally {
            DBManager.close(rs,pstmt,conn);
        }
        return infoData;
    }

    public void doHitPlus(int seq) throws Exception
    {
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY3);
            pstmt.setInt(1,seq);
            pstmt.executeUpdate();
        } finally {
            DBManager.close(pstmt,conn);
        }
    }

    public void doHitPlus(String tableName,int seq) throws Exception
    {
        String sql = "update "+tableName+" set readnum = readnum + 1 where seq =?";
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(sql);
            pstmt.setInt(1,seq);
            pstmt.executeUpdate();
        } finally {
            DBManager.close(pstmt,conn);
        }
    }
 
    public InfoTable getInfoData(int seq) throws Exception
    {
        InfoTable iTable = new InfoTable();
        ResultSet rs = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY4);
            pstmt.setInt(1,seq);
            rs = pstmt.executeQuery();
            if (rs.next()) {
                iTable.setTitle(rs.getString("title"));
                iTable.setImgInfo(rs.getString("imgInfo"));
                iTable.setWriteday(rs.getTimestamp("writeday"));
                iTable.setReadnum(rs.getInt("readnum"));
        		StringBuffer output = new StringBuffer();
        		Reader input = rs.getCharacterStream("content");
        		char[] buffer = new char[1024];
        		int byteRead;
        		while((byteRead=input.read(buffer,0,1024))!=-1){
        		  output.append(buffer,0,byteRead);
        		}
        		input.close();
                iTable.setContent(output.toString());
            }
        } finally {
            DBManager.close(rs,pstmt,conn);
        }
        return iTable;
    }

    public List getDownloadData(String tableName,int seq) throws Exception
    {
        List downloadData = new ArrayList();
        String query = "select /*+ index("+tableName+" "+tableName+"_indx) */ tbidx,fileName,fileSize,downCnt from "+tableName+" where seq=?";
        DownloadTable dTable = null;
        ResultSet rs    = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(query);
            pstmt.setInt(1,seq);
            rs = pstmt.executeQuery();
            while (rs.next()){
                dTable = new DownloadTable();
                dTable.setTbidx(rs.getInt("tbidx"));
                dTable.setFileName(rs.getString("fileName"));
                dTable.setFileSize(rs.getString("fileSize"));
                dTable.setDownCnt(rs.getInt("downCnt"));
                downloadData.add(dTable);
            }
        } finally {
            DBManager.close(rs,pstmt,conn);
        }
        return downloadData;
    }

    public List getDownloadData(String tableName,String tbName, int seq) throws Exception
    {
        List downloadData = new ArrayList();
        String query = "select /*+ index("+tableName+" "+tableName+"_indx) */ tbidx,fileName,fileSize,downCnt from "+tableName+" where tbName=? and seq=?";
        DownloadTable dTable = null;
        ResultSet rs    = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(query);
            pstmt.setString(1,tbName);
            pstmt.setInt(2,seq);
            rs = pstmt.executeQuery();
            while (rs.next()){
                dTable = new DownloadTable();
                dTable.setTbidx(rs.getInt("tbidx"));
                dTable.setFileName(rs.getString("fileName"));
                dTable.setFileSize(rs.getString("fileSize"));
                dTable.setDownCnt(rs.getInt("downCnt"));
                downloadData.add(dTable);
            }
        } finally {
            DBManager.close(rs,pstmt,conn);
        }
        return downloadData;
    }

    public BoardTable getViewData(String tableName,int seq,boolean authority,String contextRoot) throws Exception
    {
        BoardTable bTable = new BoardTable();
        String query = " select /*+ index("+tableName+" "+tableName+"_indx) */ re_step,re_level,name,title,email,content,homepage,imgInfo,writeday,readnum,ip,relativeCnt,pwd,tag from "+tableName+" where seq = ? ";
        ResultSet rs = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(query);
            pstmt.setInt(1,seq);
            rs = pstmt.executeQuery();
            if (rs.next()) {
                bTable.setRe_step(rs.getInt("re_step"));
                bTable.setRe_level(rs.getInt("re_level"));
                bTable.setName(rs.getString("name"));
                bTable.setTitle(rs.getString("title"));

                if(rs.getString("homepage") != null && !rs.getString("homepage").equals("")) {
                    if(rs.getString("homepage").indexOf("http://")>-1) 
                        bTable.setHomepage("<a href='"+rs.getString("homepage")+"' target=_blank><img src='"+contextRoot+"/kBoard/images/home.gif' border=0></a>");
                    else 
                        bTable.setHomepage("<a href='http://"+rs.getString("homepage")+"' target=_blank><img src='"+contextRoot+"/kBoard/images/home.gif' border=0></a>");
                }else
                	bTable.setHomepage("");
                if(rs.getString("email") != null && !rs.getString("email").equals("")) 
                    bTable.setEmail("<a href='mailto:"+rs.getString("email")+"'><img src='"+contextRoot+"/kBoard/images/email.gif' border=0></a>");
                else
                	bTable.setEmail("");

                bTable.setImgInfo(ParamUtil.getReqParameter(rs.getString("imgInfo")));
                bTable.setWriteday(rs.getTimestamp("writeday"));
                bTable.setReadnum(rs.getInt("readnum"));
                bTable.setIp(rs.getString("ip"));
                bTable.setRelativeCnt(rs.getInt("relativeCnt"));
                if (authority)
                	bTable.setPwd(rs.getString("pwd"));
                else
                	bTable.setPwd("");
                bTable.setTag(rs.getString("tag"));
        		StringBuffer output = new StringBuffer();
        		Reader input = rs.getCharacterStream("content");
        		char[] buffer = new char[1024];
        		int byteRead;
        		while((byteRead=input.read(buffer,0,1024))!=-1){
        			output.append(buffer,0,byteRead);
        		}
        		input.close();
                if (rs.getString("tag").equals("0")) 
                	bTable.setContent(ReplaceUtil.encodeHTMLSpecialChar(output.toString(),11));
                else 
                	bTable.setContent(output.toString()); 
            }
        } finally {
            DBManager.close(rs,pstmt,conn);
        }
        return bTable;
    }

    public List getCommentData(String tbName, int seq, boolean authority) throws Exception
    {
        List commentData = new ArrayList();
        CommentTable cTable = null;
        ResultSet rs   = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY5);
            pstmt.setString(1,tbName);
            pstmt.setInt(2,seq);
            rs = pstmt.executeQuery();
            while (rs.next()) {
                cTable = new CommentTable();
                cTable.setTbidx(rs.getInt("tbidx"));
                cTable.setCom_name(rs.getString("com_name"));
                cTable.setCom_memo(rs.getString("com_memo"));
                cTable.setCom_writeday(rs.getString("com_writeday"));
                if (authority)
                	cTable.setCom_pwd(rs.getString("com_pwd"));
                else
                	cTable.setCom_pwd("");
                commentData.add(cTable);
            }
        } finally {
            DBManager.close(rs,pstmt,conn);
        }
        return commentData;
    }

    public boolean getCheck(String tableName, int seq, String pwd) throws Exception
    {
        boolean ck = false;
        String query = "select /*+ index("+tableName+" "+tableName+"_indx) */ pwd from "+tableName+" where seq = ?";
        ResultSet rs   = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(query);
            pstmt.setInt(1,seq);
            rs = pstmt.executeQuery();
            String chkPwd = "";
            if(rs.next()) chkPwd = rs.getString(1);
            if(chkPwd.equals(pwd)) ck = true;
        } finally {
            DBManager.close(rs,pstmt,conn);
        }
        return ck;
    }

    public BoardTable getWriteData(String tableName, int seq, String pageStatus) throws Exception
    {
        String query = " select /*+ index("+tableName+" "+tableName+"_indx) */ re_step,re_level,name,title,email,content,homepage,imgInfo,tag,pwd from "+tableName+" where seq = ? ";
        BoardTable bTable = new BoardTable();
        ResultSet rs = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(query);
            pstmt.setInt(1,seq);
            rs = pstmt.executeQuery();
            if (rs.next()) {
                bTable.setRe_step(rs.getInt("re_step"));
                bTable.setRe_level(rs.getInt("re_level"));
                bTable.setEmail(rs.getString("email"));
                bTable.setTag(rs.getString("tag"));
         		StringBuffer output = new StringBuffer();
        		Reader input = rs.getCharacterStream("content");
        		char[] buffer = new char[1024];
        		int byteRead;
        		while((byteRead=input.read(buffer,0,1024))!=-1){
        		  output.append(buffer,0,byteRead);
        		}
        		input.close();
                if (rs.getString("tag").trim().equals("0")) 
                	bTable.setContent(ReplaceUtil.encodeHTMLSpecialChar(output.toString(),11));
                else 
                	bTable.setContent(output.toString()); 
                
                if (pageStatus.equals("R")) {
                    bTable.setImgInfo("");
                    bTable.setTitle("[亯]" + rs.getString("title"));
                    bTable.setPwd("");
                }else{
	                bTable.setName(rs.getString("name"));
                    bTable.setHomepage(rs.getString("homepage"));
                    bTable.setImgInfo(rs.getString("imgInfo"));
                    bTable.setTitle(rs.getString("title"));
                    bTable.setPwd(rs.getString("pwd"));
                }
            }
        } finally {
            DBManager.close(rs,pstmt,conn);
        }
        return bTable;
    }

    public void insertComment(CommentTable cTable) throws Exception
    {
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY6);
            pstmt.setString(1,cTable.getTbName());
            pstmt.setInt(2,cTable.getSeq());
            pstmt.setString(3,cTable.getCom_name());
            pstmt.setString(4,cTable.getCom_memo());
            pstmt.setString(5,cTable.getCom_pwd());
            pstmt.executeUpdate();
        }finally{
            DBManager.close(pstmt,conn);
        }
    }
    
    public void cntPlusRelative(int seq,String tableName) throws Exception
    {
        String sql = "update "+tableName+" set relativeCnt=(select /*+ index(commentmng commentmng_pk_tbidx) */ nvl(count(*),0) cnt from commentmng where tbName=? and seq=?) where seq=?";
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(sql);
            pstmt.setString(1,tableName);
            pstmt.setInt(2,seq);
            pstmt.setInt(3,seq);
            pstmt.executeUpdate();
        }finally{
            DBManager.close(pstmt,conn);
        }
    }
    
    public void deleteComment(int tbidx) throws Exception
    {
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY8);
            pstmt.setInt(1,tbidx);
            pstmt.executeUpdate();
        }finally{
            DBManager.close(pstmt,conn);
        }
    }
    
    public void deleteFile(int tbidx) throws Exception
    {
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY9);
            pstmt.setInt(1,tbidx);
            pstmt.executeUpdate();
        }finally{
            DBManager.close(pstmt,conn);
        }
    }
    
    public void deleteAllFile(String tableName,int seq,String saveDir) throws Exception
    {
        String filename = "";
        PreparedStatement pstmt = null;
        ResultSet rs = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY10);
            pstmt.setString(1,tableName);
            pstmt.setInt(2,seq);
            rs = pstmt.executeQuery();
            while (rs.next()){
                filename = rs.getString("filename");
                if (filename.length() > 3) {
                    File delFile = new File(saveDir+filename);
                    if (delFile.exists()) delFile.delete();
                }
            }
        }finally{
            DBManager.close(rs,pstmt,conn);
        }
    }
    
    public void deleteDownload(String tableName, int seq) throws Exception
    {
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY11);
            pstmt.setString(1,tableName);
            pstmt.setInt(2,seq);
            pstmt.executeUpdate();
        }finally{
            DBManager.close(pstmt,conn);
        }
    }
    
    public void commentDelete(String tableName, int seq) throws Exception
    {
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY12);
            pstmt.setString(1,tableName);
            pstmt.setInt(2,seq);
            pstmt.executeUpdate();
        }finally{
            DBManager.close(pstmt,conn);
        }
    }
    
    public void delete(int seq,String tableName) throws Exception
    {
        String sql  = "delete from "+tableName+" where seq = ?";
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(sql);
            pstmt.setInt(1,seq);
            pstmt.executeUpdate();
        }finally{
            DBManager.close(pstmt,conn);
        }
    }
    
    public void cntPlus(String tableName) throws Exception
    {
        String query = "update tablemng set tbCnt=(select /*+ index("+tableName+" "+tableName+"_pk_re_step) */ nvl(count(*),0) cnt from "+tableName+") where tbName = ?";
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(query);
            pstmt.setString(1,tableName);
            pstmt.executeUpdate();
        }finally{
            DBManager.close(pstmt,conn);
        }
    }
    
    public int deletePermission(int re_step,int re_level,String tableName) throws Exception
    {
        String delSql = "Select /*+ index_desc("+tableName+" "+tableName+"_pk_re_step) */ nvl(re_level,0) re_level from "+tableName+" where re_step > ? and re_step <? and rownum <=1";
        int del_Level = re_level;
        ResultSet rs = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(delSql);
            pstmt.setInt(1,(int)(re_step/100)*100);
            pstmt.setInt(2,re_step);
            rs = pstmt.executeQuery();
            if(rs.next()) del_Level = rs.getInt("re_level");
        }finally{
            DBManager.close(rs,pstmt,conn);
        }
        return del_Level;
    }

    public boolean getCheckComment(int tbidx,String pwd) throws Exception
    {
        boolean ck = false;
        ResultSet rs   = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY14);
            pstmt.setInt(1,tbidx);
            rs = pstmt.executeQuery();
            String chkPwd = "";
            if(rs.next()) chkPwd = rs.getString(1);
            if(chkPwd.equals(pwd)) ck = true;
        } finally {
            DBManager.close(rs,pstmt,conn);
        }
        return ck;
    }

    public int maxRef(String tableName) throws Exception  
    {
        String sql = "select /*+ index_desc("+tableName+" "+tableName+"_pk_re_step) */ re_step from "+tableName+" where rownum<=1";
        int re = 199;
        ResultSet rs = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(sql);
            rs = pstmt.executeQuery();
            if(rs.next()) re = ((int)(rs.getInt("re_step")/100) + 1) * 100 + 99;
        }finally{
            DBManager.close(rs,pstmt,conn);
        }
        return re;
    }
     
    public void insertQuery(UploadBoard up,int re_step,int re_level) throws Exception  
    {
        ResultSet rs   = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
        String query = "insert into "+up.getTableName()+" (seq,re_step,re_level,name,title,pwd,email,readnum,writeday,ip,relativeCnt,homepage,imgInfo,content,tag) values(?,?,?,?,?,?,?,0,sysdate,?,0,?,?,empty_clob(),?)";
        try{
            conn = DBManager.getConnection();
            conn.setAutoCommit(false);
            pstmt = conn.prepareStatement(query);
            pstmt.setInt(1,up.getSeq());
            pstmt.setInt(2,re_step);
            pstmt.setInt(3,re_level);
            pstmt.setString(4,up.getName());
            pstmt.setString(5,up.getTitle());
            pstmt.setString(6,up.getPwd());
            pstmt.setString(7,up.getEmail());
            pstmt.setString(8,up.getIp());
            pstmt.setString(9,up.getHomepage());
            pstmt.setString(10,up.getImgInfo());
            pstmt.setString(11,up.getTag());
            pstmt.executeUpdate();
			pstmt.close();
			
			String query2 = " select /*+ index_desc("+up.getTableName()+" "+up.getTableName()+"_indx) */ content from "+up.getTableName()+" where seq = ? for update ";
			pstmt = conn.prepareStatement(query2);
			pstmt.setInt(1,up.getSeq());
			rs = pstmt.executeQuery();
			if(rs.next()) {
				CLOB clob = ((OracleResultSet)rs).getCLOB(1);                
				Writer writer = clob.getCharacterOutputStream();
				Reader src = new CharArrayReader(up.getContent().toCharArray());
				char[] buffer = new char[1024];
				int read = 0;
				while ( (read = src.read(buffer,0,1024)) != -1) {
					writer.write(buffer, 0, read); // write clob.
				}
				src.close();                
				writer.close();
			}
			conn.commit();
			conn.setAutoCommit(true);
        }finally{
            DBManager.close(rs,pstmt,conn);
        }
    }
    
    public void getSpace(int re_step,String tableName) throws Exception
    {
        String sql = "update "+tableName+" set re_step=re_step-1 where re_step > ? and re_step < ?"; 
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(sql);
            pstmt.setInt(1,(int)(re_step/100)*100);
            pstmt.setInt(2,re_step);
            pstmt.executeUpdate();
        }finally{
            DBManager.close(pstmt,conn);
        }
    }

    public void update(UploadBoard up) throws Exception
    {
        ResultSet rs   = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
        String Msql = "update "+up.getTableName()+" set title=?,email=?,ip=?,homepage=?,imgInfo=?,content=empty_clob(),tag=? where seq = ? ";
        try{
            conn = DBManager.getConnection();
            conn.setAutoCommit(false);
            pstmt = conn.prepareStatement(Msql);
            pstmt.setString(1,up.getTitle());
            pstmt.setString(2,up.getEmail());
            pstmt.setString(3,up.getIp());
            pstmt.setString(4,up.getHomepage());
            pstmt.setString(5,up.getImgInfo());
            pstmt.setString(6,up.getTag());
            pstmt.setInt(7,up.getSeq());
            pstmt.executeUpdate();
			pstmt.close();

			String query2 = " select /*+ index_desc("+up.getTableName()+" "+up.getTableName()+"_indx) */ content from "+up.getTableName()+" where seq = ? for update ";
			pstmt = conn.prepareStatement(query2);
			pstmt.setInt(1,up.getSeq());
			rs = pstmt.executeQuery();
			if(rs.next()) {
				CLOB clob = ((OracleResultSet)rs).getCLOB(1);                
				Writer writer = clob.getCharacterOutputStream();
				Reader src = new CharArrayReader(up.getContent().toCharArray());
				char[] buffer = new char[1024];
				int read = 0;
				while ( (read = src.read(buffer,0,1024)) != -1) {
					writer.write(buffer, 0, read); // write clob.
				}
				src.close();                
				writer.close();
			}
			conn.commit();
			conn.setAutoCommit(true);
        }finally{
            DBManager.close(rs,pstmt,conn);
        }
    }

    public void insertFile(String tableName,int seq,String filename,String filesize) throws Exception 
    {
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY15);
            pstmt.setString(1,tableName);
            pstmt.setInt(2,seq);
            pstmt.setString(3,filename);
            pstmt.setString(4,filesize);
            pstmt.executeUpdate();
        }finally{
            DBManager.close(pstmt,conn);
        }
    }

    public int maxSeq(String tableName) throws Exception 
    {
        String sql = "select /*+ index_desc("+tableName+" "+tableName+"_indx) */ (nvl(seq,0)+1) seq from "+tableName+" where rownum<=1";
        ResultSet rs = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(sql);
            rs = pstmt.executeQuery();
            if(rs.next()) return rs.getInt("seq");
            else return 1;
        }finally{
            DBManager.close(rs,pstmt,conn);
        }
    }

    public void downloadHitCount(String tableName,int tbidx) throws Exception
    {
        String query = "update "+tableName+" set downCnt=downCnt+1 where tbidx=?";
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(query);
            pstmt.setInt(1,tbidx);
            pstmt.executeUpdate();
        }finally{
            DBManager.close(pstmt,conn);
        }
    }

    public String getDownloadFileName(String tableName,int tbidx) throws Exception
    {
        String query = "select fileName from "+tableName+" where tbidx=?";
        PreparedStatement pstmt = null;
        ResultSet rs = null;
        Connection conn = null;
        String returnValue = "";
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(query);
            pstmt.setInt(1,tbidx);
            rs = pstmt.executeQuery();
            if (rs.next()) {
                returnValue = rs.getString("fileName");
            }
        }finally{
            DBManager.close(rs,pstmt,conn);
        }
        return returnValue;
    }

    public String[] getPrintData(String tableName,int seq) throws Exception 
    {   
        String[] data = new String[2];
        String query = "select /*+ index("+tableName+" "+tableName+"_indx) */ content,title,tag from "+tableName+" where seq = ? ";
        PreparedStatement pstmt = null;
        ResultSet rs = null;
        Connection conn = null;
	    try{
	    	conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(query);
            pstmt.setInt(1,seq);
            rs = pstmt.executeQuery();
            if (rs.next()) {
                data[0] = rs.getString("title");
                if (rs.getString("tag").equals("0")) 
                    data[1] = ReplaceUtil.encodeHTMLSpecialChar(rs.getString("content"),11);
                else
                    data[1] = rs.getString("content");
            }
        }finally{
	    	DBManager.close(rs,pstmt,conn);
        }
        return data;
    }

    public String[] getPrintInfoData(int seq) throws Exception 
    {   
        String[] data = new String[2];
        PreparedStatement pstmt = null;
        ResultSet rs = null;
        Connection conn = null;
	    try{
	    	conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY16);
            pstmt.setInt(1,seq);
            rs = pstmt.executeQuery();
            if (rs.next()) {
                data[0] = rs.getString("title");
                data[1] = rs.getString("content");
            }
        }finally{
	    	DBManager.close(rs,pstmt,conn);
        }
        return data;
    }
}