/*
 * Author(s) kkaok
 * Date: 2003.03.14
 * Copyright kkaok,  All Rights Reserved.
 */
package kr.pe.kkaok.board.manager.dao;

import java.io.File;
import java.sql.Connection;
import java.sql.Statement;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;
import java.util.StringTokenizer;
import java.util.Vector;
import kr.pe.kkaok.jdbc.DBManager;
import kr.pe.kkaok.util.Utility;
import kr.pe.kkaok.util.ReplaceUtil;
import kr.pe.kkaok.board.manager.upload.UploadTbMng;
import kr.pe.kkaok.board.dao.*;

public class MsInfoBoardDAOImpl implements InfoBoardDAO
{
    private static final String QUERY1 = "select skin,tbTitle,attach_key,editmode,image_allow,tbCnt,tbInfoStatus from tablemng where tbName=?";
    private static final String QUERY2 = "select count(seq) cnt from tablemnginfo where tbName = ?";
    private static final String QUERY3 = "Select top 15 seq,readnum,writeday,viewSelect,title from tablemnginfo where tbName = ? and seq <= ? order by seq desc";
    private static final String QUERY4 = "select title,content,imgInfo,writeday,readnum from tablemnginfo where seq = ?";
    private static final String QUERY5 = "insert into tablemnginfo (tbName,seq,title,readnum,writeday,imgInfo,viewSelect,content) values(?,?,?,0,getdate(),?,0,?)";
    private static final String QUERY6 = "update tablemnginfo set title=?,imgInfo=?,content=? where seq = ? ";
    private static final String QUERY7 = "insert into downloadmnginfo (tbName,seq,fileName,fileSize,downCnt) values(?,?,?,?,0)";
    private static final String QUERY8 = "select max(seq) as seq from tablemnginfo";
    private static final String QUERY9 = "delete from downloadmnginfo where tbidx = ?";
    private static final String QUERY10 = "update tablemnginfo set viewSelect = ? where seq = ?";
    private static final String QUERY11 = "select filename from downloadmnginfo where tbName = ? and seq =? order by tbidx";
    private static final String QUERY12 = "delete from tablemnginfo where seq = ?";
    private static final String QUERY13 = "delete from downloadmnginfo where tbName = ? and seq = ?";
    private static final String QUERY14 = "update tablemnginfo set readnum = readnum + 1 where seq = ?";
    private static final String QUERY15 = "insert into tablemng (tbName,tbCnt,skin,tbTitle,tbInfoStatus,attach_key,editmode,image_allow) values(?,0,'1','⺸','0','0','0','0')";
    private static final String QUERY16 = "select fileName from downloadmnginfo where tbName = ? order by tbidx";
    private static final String QUERY17 = "select imgInfo from tablemnginfo where tbName = ? ";
    private static final String QUERY18 = "select tbName,tbCnt,tbInfoStatus from tablemng order by tbName";
    private static final String QUERY19 = "SELECT count(*) FROM sysobjects where name = ?";
    private static final String QUERY20 = "select skin,tbTitle,tbInfoStatus,attach_key,editmode,image_allow from tablemng where tbName=?";
    private static final String QUERY21 = "update tablemng set tbTitle=?,skin=?,tbInfoStatus=?,attach_key=?,editmode=?,image_allow=? where tbName=?";

    public SkinTable getSkinData(String tableName) throws Exception
    {
        SkinTable sTable = new SkinTable();
        ResultSet rs = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY1);
            pstmt.setString(1,tableName);
            rs = pstmt.executeQuery();
            if (rs !=null && rs.next()) {
                sTable.setSkin(rs.getString("skin"));
                sTable.setTbTitle(rs.getString("tbTitle"));
                sTable.setAttach_key(rs.getString("attach_key"));
                sTable.setEditmode(rs.getString("editmode"));
                sTable.setImage_allow(rs.getString("image_allow"));
                sTable.setTbCnt(rs.getInt("tbCnt"));
                sTable.setTbInfoStatus(rs.getString("tbInfoStatus"));
            }
        } finally {
            DBManager.close(rs,pstmt,conn);
        }
        return sTable;
    }

    public int getListCount(String tableName) throws Exception
    {
        int recordCount = 0;
        ResultSet rs = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY2);
            pstmt.setString(1,tableName);
            rs = pstmt.executeQuery();
            if(rs.next()) recordCount = rs.getInt("cnt");
        } finally {
            DBManager.close(rs,pstmt,conn);
        }
        return recordCount;
    }
        
    public List getListData(String tableName,int gotoPage,int pageSize) throws Exception
    {
        int start = pageSize*(gotoPage-1)+1;
        ResultSet rs = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
        String query = "select min(seq) AS Expr1 from (select top "+start+" seq from tablemnginfo where tbName = ? order by seq desc) as DERIVEDTBL";

        int pageTopNum = 0; 
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(query);
            pstmt.setString(1,tableName);
            rs = pstmt.executeQuery();
            if(rs.next()) pageTopNum = rs.getInt("Expr1");
        } finally {
            DBManager.close(rs,pstmt,conn);
        }
        List listData = new ArrayList();
        InfoTable iTable = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY3);
            pstmt.setString(1,tableName);
            pstmt.setInt(2,pageTopNum);
            rs = pstmt.executeQuery(); 
            while (rs.next()){
                iTable = new InfoTable();
                iTable.setSeq(rs.getInt("seq"));
                iTable.setReadnum(rs.getInt("readnum"));
                iTable.setWriteday(rs.getTimestamp("writeday"));
                iTable.setViewSelect(rs.getString("viewSelect"));
                iTable.setTitle(Utility.getTitleLimit(ReplaceUtil.encodeHTMLSpecialChar(rs.getString("title"),14),38));
                listData.add(iTable);
            }  
        } finally {
            DBManager.close(rs,pstmt,conn);
        }
        return listData;
    }

    public List getListData(String tableName,int gotoPage,int pageSize,int recordCount) throws Exception
    {
		int start = pageSize*gotoPage;
		if (start > recordCount) pageSize -= (start-recordCount);
        StringBuffer query = new StringBuffer(); 
		query.append("select seq,readnum,writeday,viewSelect,title from (select top ");
		query.append(pageSize+" seq,readnum,writeday,viewSelect,title from (select top ");
		query.append(start+" seq,readnum,writeday,viewSelect,title from tablemnginfo");
		query.append(" where tbName = ? order by seq desc) as DERIVEDTBL order by seq)as DERIVEDTBL order by seq desc");
   	
        List listData = new ArrayList();
        InfoTable iTable = null;
    	ResultSet rs = null;
    	PreparedStatement pstmt = null;
    	Connection conn = null;
    	try{
    	    conn = DBManager.getConnection();
    	    pstmt = conn.prepareStatement(query.toString());
            pstmt.setString(1,tableName);
    	    rs = pstmt.executeQuery();
    	    while(rs.next()){
                iTable = new InfoTable();
                iTable.setSeq(rs.getInt("seq"));
                iTable.setReadnum(rs.getInt("readnum"));
                iTable.setWriteday(rs.getTimestamp("writeday"));
                iTable.setViewSelect(rs.getString("viewSelect"));
                iTable.setTitle(Utility.getTitleLimit(ReplaceUtil.encodeHTMLSpecialChar(rs.getString("title"),14),38));
                listData.add(iTable);
    	    }
    	} finally{
    	    DBManager.close(pstmt,conn);
    	}
        return listData;
    }

    public int getSearchCount(String tableName,String search,String findword) throws Exception
    {
        int recordCount = 0;
        String query = "select count(seq) recordCount from tablemnginfo where tbName = ? and " + search + " like ? ";
        ResultSet rs = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(query);
            pstmt.setString(1,tableName);
            pstmt.setString(2,"%"+findword+"%");
            rs = pstmt.executeQuery();
            if(rs.next()) recordCount = rs.getInt("recordCount");
        } finally {
            DBManager.close(rs,pstmt,conn);
        }
        return recordCount;
    }

    public List getSearchData(String tableName,String search,String findword,int gotoPage,int pageSize) throws Exception
    {
        int start = pageSize*(gotoPage-1)+1;
        ResultSet rs = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
        String query = "select min(seq) AS Expr1 from (select top "+start+" seq from tablemnginfo where tbName = ? and "+ search +" like ? order by seq desc) as DERIVEDTBL";
        int pageTopNum = 0; 
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(query);
            pstmt.setString(1,tableName);
            pstmt.setString(2,"%"+findword+"%");
            rs = pstmt.executeQuery();
            if(rs.next()) pageTopNum = rs.getInt("Expr1");
        } finally {
            DBManager.close(rs,pstmt,conn);
        }

        List listData = new ArrayList();
        query = "Select top 15 seq,readnum,writeday,viewSelect,title from tablemnginfo where tbName = ? and seq <= ? and "+ search +" like ? order by seq desc";
        InfoTable iTable = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(query);
            pstmt.setString(1,tableName);
            pstmt.setInt(2,pageTopNum);
            pstmt.setString(3,"%"+findword+"%");
            rs = pstmt.executeQuery(); 
            while (rs.next()){
                iTable = new InfoTable();
                iTable.setSeq(rs.getInt("seq"));
                iTable.setReadnum(rs.getInt("readnum"));
                iTable.setWriteday(rs.getTimestamp("writeday"));
                iTable.setViewSelect(rs.getString("viewSelect"));
                iTable.setTitle(Utility.getTitleLimit(ReplaceUtil.encodeHTMLSpecialChar(rs.getString("title"),14),38));
                listData.add(iTable);
            }  
        } finally {
            DBManager.close(rs,pstmt,conn);
        }
        return listData;
    }     

    public List getSearchData(String tableName,String search,String findword,
    		int gotoPage,int pageSize,int recordCount) throws Exception
    {
		int start = pageSize*gotoPage;
		if (start > recordCount) pageSize -= (start-recordCount);
        StringBuffer query = new StringBuffer(); 
		query.append("select seq,readnum,writeday,viewSelect,title from (select top ");
		query.append(pageSize+" seq,readnum,writeday,viewSelect,title from (select top ");
		query.append(start+" seq,readnum,writeday,viewSelect,title from tablemnginfo");
		query.append(" where tbName = ? and "+ search +" like ? order by seq desc) as DERIVEDTBL");
		query.append(" order by seq)as DERIVEDTBL order by seq desc");

        List listData = new ArrayList();
        InfoTable iTable = null;
    	ResultSet rs = null;
    	PreparedStatement pstmt = null;
    	Connection conn = null;
    	try{
    	    conn = DBManager.getConnection();
    	    pstmt = conn.prepareStatement(query.toString());
            pstmt.setString(1,tableName);
            pstmt.setString(2,"%"+findword+"%");
    	    rs = pstmt.executeQuery();
    	    while(rs.next()){
                iTable = new InfoTable();
                iTable.setSeq(rs.getInt("seq"));
                iTable.setReadnum(rs.getInt("readnum"));
                iTable.setWriteday(rs.getTimestamp("writeday"));
                iTable.setViewSelect(rs.getString("viewSelect"));
                iTable.setTitle(Utility.getTitleLimit(ReplaceUtil.encodeHTMLSpecialChar(rs.getString("title"),14),38));
                listData.add(iTable);
    	    }
    	} finally{
    	    DBManager.close(pstmt,conn);
    	}
        return listData;
    }

    public InfoTable getInfoData(int seq) throws Exception
    {
        InfoTable iTable = new InfoTable();
        ResultSet rs = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY4);
            pstmt.setInt(1,seq);
            rs = pstmt.executeQuery();
            if (rs !=null && rs.next()) {
                iTable.setTitle(rs.getString("title"));
                iTable.setContent(rs.getString("content"));
                iTable.setImgInfo(rs.getString("imgInfo"));
                iTable.setWriteday(rs.getTimestamp("writeday"));
                iTable.setReadnum(rs.getInt("readnum"));
            }
        } finally {
            DBManager.close(rs,pstmt,conn);
        }
        return iTable;
    }

    public List getDownloadData(String tableName, String tbName, int seq) throws Exception
    {
        List downloadData = new ArrayList();
        String query = "select tbidx,fileName,fileSize,downCnt from "+tableName+" where tbName = ? and seq=?";
        DownloadTable dTable = null;
        ResultSet rs    = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(query);
            pstmt.setString(1,tbName);
            pstmt.setInt(2,seq);
            rs = pstmt.executeQuery();
            while (rs.next()){
                dTable = new DownloadTable();
                dTable.setTbidx(rs.getInt("tbidx"));
                dTable.setFileName(rs.getString("fileName"));
                dTable.setFileSize(rs.getString("fileSize"));
                dTable.setDownCnt(rs.getInt("downCnt"));
                downloadData.add(dTable);
            }
        } finally {
            DBManager.close(rs,pstmt,conn);
        }
        return downloadData;
    }

    public void insertQuery(UploadTbMng up) throws Exception
    {
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY5);
            pstmt.setString(1,up.getTableName());
            pstmt.setInt(2,up.getSeq());
            pstmt.setString(3,up.getTitle());
            pstmt.setString(4,up.getImgInfo());
            pstmt.setString(5,up.getContent());
            pstmt.executeUpdate();
        }finally{
            DBManager.close(pstmt,conn);
        }
    }

    public void update(UploadTbMng up) throws Exception
    {
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY6);
            pstmt.setString(1,up.getTitle());
            pstmt.setString(2,up.getImgInfo());
            pstmt.setString(3,up.getContent());
            pstmt.setInt(4,up.getSeq());
            pstmt.executeUpdate();
        }finally{
            DBManager.close(pstmt,conn);
        }   
    }
    
    public void insertFile(String tableName,int seq,String filename,String filesize) throws Exception 
    {
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY7);
            pstmt.setString(1,tableName);
            pstmt.setInt(2,seq);
            pstmt.setString(3,filename);
            pstmt.setString(4,filesize);
            pstmt.executeUpdate();
        }finally{
            DBManager.close(pstmt,conn);
        }
    }

    public int maxSeq() throws Exception 
    {
        int id = 0;
        ResultSet rs = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY8);
            rs = pstmt.executeQuery();
            if(rs.next()){
                id = rs.getInt("seq")+1;
            }else{
                id = 1;
            }  
        }finally{
            DBManager.close(rs,pstmt,conn);
        }
        return id;
    }

    public void deleteFile(int tbidx) throws Exception 
    {
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY9);
            pstmt.setInt(1,tbidx);
            pstmt.executeUpdate();
        }finally{
            DBManager.close(pstmt,conn);
        }
    }

    public void alterViewStatus(String viewSelect, int seq) throws Exception
    {
        String alterValue = "0";
        if (viewSelect.equals("0")) alterValue = "1";
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY10);
            pstmt.setString(1,alterValue);
            pstmt.setInt(2,seq);
            pstmt.executeUpdate();
        }finally{
            DBManager.close(pstmt,conn);
        }
    }

    public void deleteAllFile(String tableName,int seq,String saveDir) throws Exception
    {
        String filename = "";
        PreparedStatement pstmt = null;
        ResultSet rs = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY11);
            pstmt.setString(1,tableName);
            pstmt.setInt(2,seq);
            rs = pstmt.executeQuery();
            while (rs.next()){
                filename = rs.getString("filename");
                if (filename.length() > 3) {
                    File delFile = new File(saveDir+filename);
                    if (delFile.exists()) delFile.delete();
                }
            }
        }finally{
            DBManager.close(rs,pstmt,conn);
        }
    }

    public void delete(int seq) throws Exception
    {
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY12);
            pstmt.setInt(1,seq);
            pstmt.executeUpdate();
        }finally{
            DBManager.close(pstmt,conn);
        }
    }

    public void deleteDownload(String tableName, int seq) throws Exception
    {
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY13);
            pstmt.setString(1,tableName);
            pstmt.setInt(2,seq);
            pstmt.executeUpdate();
        } finally{
            DBManager.close(pstmt,conn);
        }
    }

    public void doHitPlus(int seq) throws Exception
    {
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY14);
            pstmt.setInt(1,seq);
            pstmt.executeUpdate();
        } finally {
            DBManager.close(pstmt,conn);
        }
    } 

    public void createTable(String tableName) throws Exception
    {
        StringBuffer query = new StringBuffer();
        query.append("CREATE TABLE "+tableName+"(");
        query.append("seq int NOT NULL ,");
        query.append("re_level tinyint NOT NULL ,");
        query.append("re_step int NOT NULL PRIMARY KEY,");
        query.append("name varchar(20) NOT NULL ,");
        query.append("title varchar(100) NOT NULL ,");
        query.append("content text NOT NULL ,");
        query.append("pwd varchar(10) NOT NULL ,");
        query.append("email varchar(50) NULL ,");
        query.append("homepage varchar(100) NULL ,");
        query.append("readnum int NOT NULL ,");
        query.append("tag char(1) NOT NULL ,");
        query.append("writeday datetime NOT NULL DEFAULT (getdate()),");
        query.append("ip varchar(24) NOT NULL ,");
        query.append("imgInfo varchar(300) NULL ,");
        query.append("relativeCnt int NOT NULL) ");

        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(query.toString());
            pstmt.executeUpdate();
        } finally {
            DBManager.close(pstmt,conn);
        }

        String qry = "CREATE INDEX [IX_"+tableName+"] ON "+tableName+"([seq]) ON [PRIMARY]";
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(qry);
            pstmt.executeUpdate();
        } finally {
            DBManager.close(pstmt,conn);
        }
    }
  
    public void insertInfo(String tableName) throws Exception
    {
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY15);
            pstmt.setString(1,tableName);
            pstmt.executeUpdate();
        } finally{
            DBManager.close(pstmt,conn);
        }
    }

    public void dropTable(String tableName) throws Exception
    {
        String query = "drop TABLE "+tableName;
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(query);
            pstmt.executeUpdate();
        }finally{
            DBManager.close(pstmt,conn);
        }
    }
  
    public void deleteTable(String tableName,String tbName) throws Exception
    {
        String query = "delete from "+tableName+" where tbName = ?"; 
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(query);
            pstmt.setString(1,tbName);
            pstmt.executeUpdate();
        }finally{
            DBManager.close(pstmt,conn);
        }
    }
  
    public void infoFileDelete(String delInfoDir,String tbName) throws Exception
    {
        File delFile = null; 
        ResultSet rs    = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY16);
            pstmt.setString(1,tbName);
            rs = pstmt.executeQuery();
            while (rs.next()){
                delFile = new File(delInfoDir + rs.getString("fileName").trim());
                if (delFile.exists()) delFile.delete();
            }
        } finally {
            DBManager.close(rs,pstmt,conn);
        }
    } 
  
    public void infoImgDelete(String delImgDir,String tbName) throws Exception
    {
        String imgInfo = ""; 
        File delImg = null; 
        Vector vec    = new Vector();
        int    vecLen = 0;
        ResultSet rs  = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY17);
            pstmt.setString(1,tbName);
            rs = pstmt.executeQuery();
            while (rs.next()){
                if (rs.getString("imgInfo") != null && !rs.getString("imgInfo").equals(""))
                    vec.addElement(rs.getString("imgInfo").trim());
            }
            vecLen =  vec.size();
            for (int rowcounter=0;rowcounter<vecLen;rowcounter++){
                imgInfo = vec.elementAt(rowcounter).toString();
                StringTokenizer st = new StringTokenizer(imgInfo,"/");
                while (st.hasMoreTokens()) {
                    delImg = new File(delImgDir+st.nextElement());
                    if (delImg.exists()) delImg.delete();
                }
            }
        } finally {
            DBManager.close(rs,pstmt,conn);
        }
    } 

    public List getTableData() throws Exception
    {
        List listData = new ArrayList();
        SkinTable sTable = null;
        ResultSet rs   = null;
        PreparedStatement pstmt  = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY18);
            rs = pstmt.executeQuery(); 
            while (rs.next()){
                sTable = new SkinTable();
                sTable.setTbName(rs.getString("tbName"));
                sTable.setTbCnt(rs.getInt("tbCnt"));
                sTable.setTbInfoStatus(rs.getString("tbInfoStatus"));
                listData.add(sTable);
            }
        } finally {
            DBManager.close(rs,pstmt,conn);
        }
        return listData;
    }

    public boolean checkTablePermission(String id) throws Exception
    {
        boolean cnt = false;
        ResultSet rs = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY19);
            pstmt.setString(1,id);
            rs = pstmt.executeQuery();
            if(rs.next()){
                if(rs.getInt(1)>0) cnt = true;
            }
        }finally{
            DBManager.close(rs,pstmt,conn);
        }
        return cnt;
    }

    public SkinTable getSkinDataInfo(String tableName) throws Exception
    {
        SkinTable sTable = new SkinTable();
        ResultSet rs = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY20);
            pstmt.setString(1,tableName);
            rs = pstmt.executeQuery();
            if (rs !=null && rs.next()) {
                sTable.setSkin(rs.getString("skin"));
                sTable.setTbTitle(rs.getString("tbTitle"));
                sTable.setAttach_key(rs.getString("attach_key"));
                sTable.setEditmode(rs.getString("editmode"));
                sTable.setImage_allow(rs.getString("image_allow"));
                sTable.setTbInfoStatus(rs.getString("tbInfoStatus"));
            }
        }finally{
            DBManager.close(rs,pstmt,conn);
        }
        return sTable;
    }

    public void doSkinUpdate(SkinTable sTable) throws Exception
    {
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY21);
            pstmt.setString(1,sTable.getTbTitle());
            pstmt.setString(2,sTable.getSkin());
            pstmt.setString(3,sTable.getTbInfoStatus());
            pstmt.setString(4,sTable.getAttach_key());
            pstmt.setString(5,sTable.getEditmode());
            pstmt.setString(6,sTable.getImage_allow());
            pstmt.setString(7,sTable.getTbName());
            pstmt.executeUpdate();
        }finally{
            DBManager.close(pstmt,conn);
        }
    }
}