/*
 * Author(s) kkaok
 * Date: 2003.03.14
 * Copyright kkaok,  All Rights Reserved.
 */
package kr.pe.kkaok.board.manager.dao;

import java.io.File;
import java.io.Reader;
import java.io.Writer;
import java.io.CharArrayReader;
import java.sql.Connection;
import java.sql.Statement;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;
import java.util.StringTokenizer;
import java.util.Vector;
import oracle.sql.*;
import oracle.jdbc.driver.*;
import kr.pe.kkaok.jdbc.DBManager;
import kr.pe.kkaok.util.Utility;
import kr.pe.kkaok.util.ReplaceUtil;
import kr.pe.kkaok.board.manager.upload.UploadTbMng;
import kr.pe.kkaok.board.dao.*;

public class OraInfoBoardDAOImpl implements InfoBoardDAO
{
    private static final String QUERY1 = "select /*+ index(tablemng tablemng_pk_tbname) */ skin,tbTitle,attach_key,editmode,image_allow,tbCnt,tbInfoStatus from tablemng where tbName=?";
    private static final String QUERY2 = "select /*+ index_desc(tablemnginfo tablemnginfo_indx) */ count(seq) cnt from tablemnginfo where tbName = ?";
    private static final String QUERY4 = "select /*+ index(tablemnginfo tablemnginfo_pk_seq) */ title,content,imgInfo,writeday,readnum from tablemnginfo where seq = ?";
    private static final String QUERY5 = "insert into tablemnginfo (tbName,seq,title,readnum,writeday,imgInfo,viewSelect,content) values(?,?,?,0,sysdate,?,0,empty_clob())";
    private static final String QUERY6 = "update tablemnginfo set title=?,imgInfo=?,content=empty_clob() where seq = ? ";
    private static final String QUERY7 = "insert into downloadmnginfo (tbName,seq,tbidx,fileName,fileSize,downCnt) values(?,?,downloadmnginfo_tbidx.NEXTVAL,?,?,0)";
    private static final String QUERY8 = "select /*+ index_desc(tablemnginfo tablemnginfo_pk_seq) */ (nvl(seq,0)+1) seq from tablemnginfo where rownum<=1";
    private static final String QUERY9 = "delete from downloadmnginfo where tbidx = ?";
    private static final String QUERY10 = "update tablemnginfo set viewSelect = ? where seq = ?";
    private static final String QUERY11 = "select /*+ index(downloadmnginfo downloadmnginfo_indx) */ filename from downloadmnginfo where tbName = ? and seq =?";
    private static final String QUERY12 = "delete from tablemnginfo where seq = ?";
    private static final String QUERY13 = "delete from downloadmnginfo where tbName = ? and seq = ?";
    private static final String QUERY14 = "update tablemnginfo set readnum = readnum + 1 where seq = ?";
    private static final String QUERY15 = "insert into tablemng (tbName,tbCnt,skin,tbTitle,tbInfoStatus,attach_key,editmode,image_allow) values(?,0,'1','⺸','0','0','0','0')";
    private static final String QUERY16 = "select /*+ index(downloadmnginfo downloadmnginfo_indx) */ fileName from downloadmnginfo where tbName = ?";
    private static final String QUERY17 = "select /*+ index(tablemnginfo tablemnginfo_indx) */ imgInfo from tablemnginfo where tbName = ? ";
    private static final String QUERY18 = "select /*+ index(tablemng tablemng_pk_tbname) */ tbName,tbCnt,tbInfoStatus from tablemng";
    private static final String QUERY19 = "select nvl(count(*),0) cnt from TAB where TNAME = ?"; 
    private static final String QUERY20 = "select /*+ index(tablemnginfo tablemnginfo_indx) */ skin,tbTitle,tbInfoStatus,attach_key,editmode,image_allow from tablemng where tbName=?";
    private static final String QUERY21 = "update tablemng set tbTitle=?,skin=?,tbInfoStatus=?,attach_key=?,editmode=?,image_allow=? where tbName=?";
    private static final String QUERY22 = "select min(seq) seq from (select /*+ index_desc(tablemnginfo tablemnginfo_indx) */ seq from tablemnginfo where tbName = ? and rownum <=?) c"; 
    private static final String QUERY23 = "select /*+ index_desc(tablemnginfo tablemnginfo_indx) */ seq,readnum,writeday,viewSelect,title from tablemnginfo where tbName = ? and seq<= ? and rownum <=?";
    private static final String QUERY24 = "select /*+ index(tablemnginfo tablemnginfo_pk_seq) */ content from tablemnginfo where seq=? for update ";

    public SkinTable getSkinData(String tableName) throws Exception
    {
        SkinTable sTable = new SkinTable();
        ResultSet rs = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY1);
            pstmt.setString(1,tableName);
            rs = pstmt.executeQuery();
            if (rs !=null && rs.next()) {
                sTable.setSkin(rs.getString("skin"));
                sTable.setTbTitle(rs.getString("tbTitle"));
                sTable.setAttach_key(rs.getString("attach_key"));
                sTable.setEditmode(rs.getString("editmode"));
                sTable.setImage_allow(rs.getString("image_allow"));
                sTable.setTbCnt(rs.getInt("tbCnt"));
                sTable.setTbInfoStatus(rs.getString("tbInfoStatus"));
            }
        } finally {
            DBManager.close(rs,pstmt,conn);
        }
        return sTable;
    }

    public int getListCount(String tableName) throws Exception
    {
        int recordCount = 0;
        ResultSet rs = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY2);
            pstmt.setString(1,tableName);
            rs = pstmt.executeQuery();
            if(rs.next()) recordCount = rs.getInt("cnt");
        } finally {
            DBManager.close(rs,pstmt,conn);
        }
        return recordCount;
    }
        
    public List getListData(String tableName,int gotoPage,int pageSize) throws Exception
    {
        ResultSet rs = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
     
        int start = pageSize*(gotoPage-1)+1;
        int pageTopNum = 0; 
        try {
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY22);
            pstmt.setString(1,tableName);
            pstmt.setInt(2,start);
            rs = pstmt.executeQuery();
            if(rs.next()) pageTopNum = rs.getInt("seq");
            else pageTopNum = 0;
        } finally {
            DBManager.close(rs,pstmt,conn);
        }

        List listData = new ArrayList();
        InfoTable iTable = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY23);
            pstmt.setString(1,tableName);
            pstmt.setInt(2,pageTopNum);
            pstmt.setInt(3,pageSize);
            rs = pstmt.executeQuery(); 
            while (rs.next()){
                iTable = new InfoTable();
                iTable.setSeq(rs.getInt("seq"));
                iTable.setReadnum(rs.getInt("readnum"));
                iTable.setWriteday(rs.getTimestamp("writeday"));
                iTable.setViewSelect(rs.getString("viewSelect"));
                iTable.setTitle(Utility.getTitleLimit(ReplaceUtil.encodeHTMLSpecialChar(rs.getString("title"),14),38));
                listData.add(iTable);
            }  
        } finally {
            DBManager.close(rs,pstmt,conn);
        }
        return listData;
    }

    public List getListData(String tableName,int gotoPage,int pageSize,int recordCount) throws Exception
    {
    	StringBuffer QUERY3 = new StringBuffer();
		QUERY3.append("select seq,readnum,writeday,viewSelect,title from (select ");
		QUERY3.append("/*+ index_desc(tablemnginfo tablemnginfo_indx) */ ");
		QUERY3.append("seq,readnum,writeday,viewSelect,title,rownum as rnum from tablemnginfo where ");
		QUERY3.append("tbName = ? and rownum <= ? order by rnum desc) where rownum <= ? order by rnum");

		int start = pageSize*gotoPage;
		if (start > recordCount) pageSize -= (start-recordCount);
        List listData = new ArrayList();
        InfoTable iTable = null;
        ResultSet rs   = null;
        PreparedStatement pstmt  = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY3.toString());
            pstmt.setString(1,tableName);
            pstmt.setInt(2,start);
            pstmt.setInt(3,pageSize);
            rs = pstmt.executeQuery(); 
            while (rs.next()){
                iTable = new InfoTable();
                iTable.setSeq(rs.getInt("seq"));
                iTable.setReadnum(rs.getInt("readnum"));
                iTable.setWriteday(rs.getTimestamp("writeday"));
                iTable.setViewSelect(rs.getString("viewSelect"));
                iTable.setTitle(Utility.getTitleLimit(ReplaceUtil.encodeHTMLSpecialChar(rs.getString("title"),14),38));
                listData.add(iTable);
            }  
        } finally {
            DBManager.close(rs,pstmt,conn);
        }
        return listData;
    }

    public int getSearchCount(String tableName,String search,String findword) throws Exception
    {
		String ex_query = "";
		if(search.equals("content")){
			ex_query = " dbms_lob.instr(content, ?)>0 ";
		}else{
			ex_query = search + " like '%'||?||'%' ";
		}
        int recordCount = 0;
        String query = "select /*+ index_desc(tablemnginfo tablemnginfo_indx) */ count(seq) recordCount from tablemnginfo where tbName = ? and " + ex_query;
        ResultSet rs = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(query);
            pstmt.setString(1,tableName);
            pstmt.setString(2,findword);
            rs = pstmt.executeQuery();
            if(rs.next()) recordCount = rs.getInt("recordCount");
        } finally {
            DBManager.close(rs,pstmt,conn);
        }
        return recordCount;
    }

    public List getSearchData(String tableName,String search,String findword,
    		int gotoPage,int pageSize,int recordCount) throws Exception
    {
		String ex_query = "";
		if(search.equals("content")){
			ex_query = " dbms_lob.instr(content, ?)>0 ";
		}else{
			ex_query = search + " like '%'||?||'%' ";
		}
		int start = pageSize*gotoPage;
		if (start > recordCount) pageSize -= (start-recordCount);

    	StringBuffer query = new StringBuffer();
		query.append("select seq,readnum,writeday,viewSelect,title from (select ");
		query.append("/*+ index_desc(tablemnginfo tablemnginfo_indx) */ ");
		query.append("seq,readnum,writeday,viewSelect,title,rownum as rnum from tablemnginfo where ");
		query.append("tbName = ? and "+ex_query+" and rownum <= ? order by rnum desc) where rownum <= ? order by rnum");

        List listData = new ArrayList();
        InfoTable iTable = null;
        ResultSet rs   = null;
        PreparedStatement pstmt  = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(query.toString());
            pstmt.setString(1,tableName);
            pstmt.setString(2,findword);
            pstmt.setInt(3,start);
            pstmt.setInt(4,pageSize);
            rs = pstmt.executeQuery(); 
            while (rs.next()){
                iTable = new InfoTable();
                iTable.setSeq(rs.getInt("seq"));
                iTable.setReadnum(rs.getInt("readnum"));
                iTable.setWriteday(rs.getTimestamp("writeday"));
                iTable.setViewSelect(rs.getString("viewSelect"));
                iTable.setTitle(Utility.getTitleLimit(ReplaceUtil.encodeHTMLSpecialChar(rs.getString("title"),14),38));
                listData.add(iTable);
            }  
        } finally {
            DBManager.close(rs,pstmt,conn);
        }
        return listData;
	}

    public List getSearchData(String tableName,String search,String findword,
    		int gotoPage,int pageSize) throws Exception
    {
		String ex_query = "";
		if(search.equals("content")){
			ex_query = " dbms_lob.instr(content, ?)>0 ";
		}else{
			ex_query = search + " like '%'||?||'%' ";
		}

        ResultSet rs = null;
        PreparedStatement pstmt = null;
        Connection conn = null;

    	String query = "select min(seq) seq from (select /*+ index_desc(tablemnginfo tablemnginfo_indx) */ seq from tablemnginfo where tbName = ? and "+ex_query+" and rownum <=?) c"; 

        int start = pageSize*(gotoPage-1)+1;
        int pageTopNum = 0; 
        try {
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(query);
            pstmt.setString(1,tableName);
            pstmt.setString(2,findword);
            pstmt.setInt(3,start);
            rs = pstmt.executeQuery();
            if(rs.next()) pageTopNum = rs.getInt("seq");
            else pageTopNum = 0;
        } finally {
            DBManager.close(rs,pstmt,conn);
        }

        query = "select /*+ index_desc(tablemnginfo tablemnginfo_indx) */ seq,readnum,writeday,viewSelect,title from tablemnginfo where tbName = ? and seq<= ? and "+ex_query+" and rownum <=?";
        List listData = new ArrayList();
        InfoTable iTable = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(query);
            pstmt.setString(1,tableName);
            pstmt.setInt(2,pageTopNum);
            pstmt.setString(3,findword);
            pstmt.setInt(4,pageSize);
            rs = pstmt.executeQuery(); 
            while (rs.next()){
                iTable = new InfoTable();
                iTable.setSeq(rs.getInt("seq"));
                iTable.setReadnum(rs.getInt("readnum"));
                iTable.setWriteday(rs.getTimestamp("writeday"));
                iTable.setViewSelect(rs.getString("viewSelect"));
                iTable.setTitle(Utility.getTitleLimit(ReplaceUtil.encodeHTMLSpecialChar(rs.getString("title"),14),38));
                listData.add(iTable);
            }  
        } finally {
            DBManager.close(rs,pstmt,conn);
        }
        return listData;
    }

    public InfoTable getInfoData(int seq) throws Exception
    {
        InfoTable iTable = new InfoTable();
        ResultSet rs = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY4);
            pstmt.setInt(1,seq);
            rs = pstmt.executeQuery();
            if (rs !=null && rs.next()) {
                iTable.setTitle(rs.getString("title"));
                iTable.setImgInfo(rs.getString("imgInfo"));
                iTable.setWriteday(rs.getTimestamp("writeday"));
                iTable.setReadnum(rs.getInt("readnum"));
        		StringBuffer output = new StringBuffer();
        		Reader input = rs.getCharacterStream("content");
        		char[] buffer = new char[1024];
        		int byteRead;
        		while((byteRead=input.read(buffer,0,1024))!=-1){
        		  output.append(buffer,0,byteRead);
        		}
        		input.close();
                iTable.setContent(output.toString());
            }
        } finally {
            DBManager.close(rs,pstmt,conn);
        }
        return iTable;
    }

    public List getDownloadData(String tableName, String tbName, int seq) throws Exception
    {
        List downloadData = new ArrayList();
        String query = "select /*+ index(downloadmnginfo downloadmnginfo_indx) */ tbidx,fileName,fileSize,downCnt from "+tableName+" where tbName = ? and seq=?";
        DownloadTable dTable = null;
        ResultSet rs    = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(query);
            pstmt.setString(1,tbName);
            pstmt.setInt(2,seq);
            rs = pstmt.executeQuery();
            while (rs.next()){
                dTable = new DownloadTable();
                dTable.setTbidx(rs.getInt("tbidx"));
                dTable.setFileName(rs.getString("fileName"));
                dTable.setFileSize(rs.getString("fileSize"));
                dTable.setDownCnt(rs.getInt("downCnt"));
                downloadData.add(dTable);
            }
        } finally {
            DBManager.close(rs,pstmt,conn);
        }
        return downloadData;
    }

    public void insertQuery(UploadTbMng up) throws Exception
    {
        ResultSet rs    = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            conn.setAutoCommit(false);
            pstmt = conn.prepareStatement(QUERY5);
            pstmt.setString(1,up.getTableName());
            pstmt.setInt(2,up.getSeq());
            pstmt.setString(3,up.getTitle());
            pstmt.setString(4,up.getImgInfo());
            pstmt.executeUpdate();
			pstmt.close();

			pstmt = conn.prepareStatement(QUERY24);
			pstmt.setInt(1,up.getSeq());
			rs = pstmt.executeQuery();
			while (rs.next()) {
				CLOB clob = ((OracleResultSet)rs).getCLOB(1);                
				Writer writer = clob.getCharacterOutputStream();
				Reader src = new CharArrayReader(up.getContent().toCharArray());
				char[] buffer = new char[1024];
				int read = 0;
				while ( (read = src.read(buffer,0,1024)) != -1) {
					writer.write(buffer, 0, read); // write clob.
				}
				src.close();                
				writer.close();
			}
			conn.commit();
			conn.setAutoCommit(true);
        }finally{
            DBManager.close(rs,pstmt,conn);
        }
    }

    public void update(UploadTbMng up) throws Exception
    {
        ResultSet rs    = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            conn.setAutoCommit(false);
            pstmt = conn.prepareStatement(QUERY6);
            pstmt.setString(1,up.getTitle());
            pstmt.setString(2,up.getImgInfo());
            pstmt.setInt(3,up.getSeq());
            pstmt.executeUpdate();
			pstmt.close();
			
			pstmt = conn.prepareStatement(QUERY24);
			pstmt.setInt(1,up.getSeq());
			rs = pstmt.executeQuery();
			while (rs.next()) {
				CLOB clob = ((OracleResultSet)rs).getCLOB(1);                
				Writer writer = clob.getCharacterOutputStream();
				Reader src = new CharArrayReader(up.getContent().toCharArray());
				char[] buffer = new char[1024];
				int read = 0;
				while ( (read = src.read(buffer,0,1024)) != -1) {
					writer.write(buffer, 0, read); // write clob.
				}
				src.close();                
				writer.close();
			}
			conn.commit();
			conn.setAutoCommit(true);
        }finally{
            DBManager.close(rs,pstmt,conn);
        }   
    }
    
    public void insertFile(String tableName,int seq,String filename,String filesize) throws Exception 
    {
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY7);
            pstmt.setString(1,tableName);
            pstmt.setInt(2,seq);
            pstmt.setString(3,filename);
            pstmt.setString(4,filesize);
            pstmt.executeUpdate();
        }finally{
            DBManager.close(pstmt,conn);
        }
    }

    public int maxSeq() throws Exception 
    {
        int id = 0;
        ResultSet rs = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY8);
            rs = pstmt.executeQuery();
            if(rs.next()){
                id = rs.getInt("seq");
            }else{
                id = 1;
            }
        }finally{
            DBManager.close(rs,pstmt,conn);
        }
        return id;
    }

    public void deleteFile(int tbidx) throws Exception 
    {
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY9);
            pstmt.setInt(1,tbidx);
            pstmt.executeUpdate();
        }finally{
            DBManager.close(pstmt,conn);
        }
    }

    public void alterViewStatus(String viewSelect, int seq) throws Exception
    {
        String alterValue = "0";
        if (viewSelect.equals("0")) alterValue = "1";
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY10);
            pstmt.setString(1,alterValue);
            pstmt.setInt(2,seq);
            pstmt.executeUpdate();
        }finally{
            DBManager.close(pstmt,conn);
        }
    }

    public void deleteAllFile(String tableName,int seq,String saveDir) throws Exception
    {
        String filename = "";
        PreparedStatement pstmt = null;
        ResultSet rs = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY11);
            pstmt.setString(1,tableName);
            pstmt.setInt(2,seq);
            rs = pstmt.executeQuery();
            while (rs.next()){
                filename = rs.getString("filename");
                if (filename.length() > 3) {
                    File delFile = new File(saveDir+filename);
                    if (delFile.exists()) delFile.delete();
                }
            }
        }finally{
            DBManager.close(rs,pstmt,conn);
        }
    }

    public void delete(int seq) throws Exception
    {
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY12);
            pstmt.setInt(1,seq);
            pstmt.executeUpdate();
        }finally{
            DBManager.close(pstmt,conn);
        }
    }

    public void deleteDownload(String tableName, int seq) throws Exception
    {
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY13);
            pstmt.setString(1,tableName);
            pstmt.setInt(2,seq);
            pstmt.executeUpdate();
        } finally{
            DBManager.close(pstmt,conn);
        }
    }

    public void doHitPlus(int seq) throws Exception
    {
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY14);
            pstmt.setInt(1,seq);
            pstmt.executeUpdate();
        } finally {
            DBManager.close(pstmt,conn);
        }
    }

    public void createTable(String tableName) throws Exception
    {
        StringBuffer query = new StringBuffer();
        query.append("CREATE TABLE "+tableName+" (\n");
        query.append("seq number(8) not null,\n");
        query.append("re_level number(3) DEFAULT 0 not null,\n");
        query.append("re_step number(8),\n");
        query.append("name varchar2(50) not null,\n");
        query.append("title varchar2(200) not null,\n");
        query.append("content clob not null,\n");
        query.append("pwd varchar2(8),\n");
        query.append("email varchar2(50),\n");
        query.append("homepage varchar2(100),\n");
        query.append("readnum number(8) DEFAULT 0 not null,\n");
        query.append("tag char(1) not null,\n");
        query.append("writeday date default sysdate not null,\n");
        query.append("ip varchar2(24),\n");
        query.append("imgInfo varchar2(300),\n");
        query.append("relativeCnt number(8) DEFAULT 0,\n");
        query.append("CONSTRAINT "+tableName+"_pk_re_step PRIMARY KEY (re_step)\n");
        query.append(")\n");

        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(query.toString());
            pstmt.executeUpdate();
        } finally{
            DBManager.close(pstmt,conn);
        }

	    String sql = "create unique index "+tableName+"_indx on "+tableName+"(seq)";
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(sql);
            pstmt.executeUpdate();
        } finally {
            DBManager.close(pstmt,conn);
        }
    }
  
    public void insertInfo(String tableName) throws Exception
    {
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY15);
            pstmt.setString(1,tableName);
            pstmt.executeUpdate();
        } finally{
            DBManager.close(pstmt,conn);
        }
    }

    public void dropTable(String tableName) throws Exception
    {
        String query = "drop TABLE "+tableName;
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(query);
            pstmt.executeUpdate();
        }finally{
            DBManager.close(pstmt,conn);
        }
    }
  
    public void deleteTable(String tableName,String tbName) throws Exception
    {
        String query = "delete from "+tableName+" where tbName = ?"; 
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(query);
            pstmt.setString(1,tbName);
            pstmt.executeUpdate();
        }finally{
            DBManager.close(pstmt,conn);
        }
    }
  
    public void infoFileDelete(String delInfoDir,String tbName) throws Exception
    {
        File delFile = null; 
        ResultSet rs    = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY16);
            pstmt.setString(1,tbName);
            rs = pstmt.executeQuery();
            while (rs.next()){
                delFile = new File(delInfoDir + rs.getString("fileName").trim());
                if (delFile.exists()) delFile.delete();
            }
        } finally {
            DBManager.close(rs,pstmt,conn);
        }
    } 
  
    public void infoImgDelete(String delImgDir,String tbName) throws Exception
    {
        String imgInfo = ""; 
        File delImg = null; 
        Vector vec    = new Vector();
        int    vecLen = 0;
        ResultSet rs  = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY17);
            pstmt.setString(1,tbName);
            rs = pstmt.executeQuery();
            while (rs.next()){
                if (rs.getString("imgInfo") != null && !rs.getString("imgInfo").equals(""))
                    vec.addElement(rs.getString("imgInfo").trim());
            }
            vecLen =  vec.size();
            for (int rowcounter=0;rowcounter<vecLen;rowcounter++){
                imgInfo = vec.elementAt(rowcounter).toString();
                StringTokenizer st = new StringTokenizer(imgInfo,"/");
                while (st.hasMoreTokens()) {
                    delImg = new File(delImgDir+st.nextElement());
                    if (delImg.exists()) delImg.delete();
                }
            }
        } finally {
            DBManager.close(rs,pstmt,conn);
        }
    } 

    public List getTableData() throws Exception
    {
        List listData = new ArrayList();
        SkinTable sTable = null;
        ResultSet rs   = null;
        PreparedStatement pstmt  = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY18);
            rs = pstmt.executeQuery(); 
            while (rs.next()){
                sTable = new SkinTable();
                sTable.setTbName(rs.getString("tbName"));
                sTable.setTbCnt(rs.getInt("tbCnt"));
                sTable.setTbInfoStatus(rs.getString("tbInfoStatus"));
                listData.add(sTable);
            }
        } finally {
            DBManager.close(rs,pstmt,conn);
        }
        return listData;
    }

    public boolean checkTablePermission(String id) throws Exception
    {
        boolean cnt = false;
        ResultSet rs = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY19);
            pstmt.setString(1,id.toUpperCase());
            rs = pstmt.executeQuery();
            if(rs.next()){
                if(rs.getInt(1)>0) cnt = true;
            }
        }finally{
            DBManager.close(rs,pstmt,conn);
        }
        return cnt;
    }

    public SkinTable getSkinDataInfo(String tableName) throws Exception
    {
        SkinTable sTable = new SkinTable();
        ResultSet rs = null;
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY20);
            pstmt.setString(1,tableName);
            rs = pstmt.executeQuery();
            if (rs !=null && rs.next()) {
                sTable.setSkin(rs.getString("skin"));
                sTable.setTbTitle(rs.getString("tbTitle"));
                sTable.setAttach_key(rs.getString("attach_key"));
                sTable.setEditmode(rs.getString("editmode"));
                sTable.setImage_allow(rs.getString("image_allow"));
                sTable.setTbInfoStatus(rs.getString("tbInfoStatus"));
            }
        }finally{
            DBManager.close(rs,pstmt,conn);
        }
        return sTable;
    }

    public void doSkinUpdate(SkinTable sTable) throws Exception
    {
        PreparedStatement pstmt = null;
        Connection conn = null;
        try{
            conn = DBManager.getConnection();
            pstmt = conn.prepareStatement(QUERY21);
            pstmt.setString(1,sTable.getTbTitle());
            pstmt.setString(2,sTable.getSkin());
            pstmt.setString(3,sTable.getTbInfoStatus());
            pstmt.setString(4,sTable.getAttach_key());
            pstmt.setString(5,sTable.getEditmode());
            pstmt.setString(6,sTable.getImage_allow());
            pstmt.setString(7,sTable.getTbName());
            pstmt.executeUpdate();
        }finally{
            DBManager.close(pstmt,conn);
        }
    }
}